@@ -14,22 +14,22 @@ set -e
 BUILDER_IMAGE="quay.io/coreos/tectonic-console-builder:v19"
 
 # forward whitelisted env variables to docker
-ENV_STR=""
-VOLUME_MOUNT=""
+ENV_STR=()
+VOLUME_MOUNT=()
 for VAR in ${DOCKER_ENV//,/ }; do
     if [ "$VAR" = 'KUBECONFIG' ]
     then
-      VOLUME_MOUNT="-v $KUBECONFIG:/kube/config"
-      ENV_STR="$ENV_STR -e KUBECONFIG=/kube/config"
+      VOLUME_MOUNT=("-v" "$KUBECONFIG:/kube/config")
+      ENV_STR+=("-e" "KUBECONFIG=/kube/config")
     else
-      ENV_STR="$ENV_STR -e $VAR=${!VAR}"
+      ENV_STR+=("-e" "$VAR=${!VAR}")
     fi
 done
 
-docker run $ENV_STR --rm --net=host \
+docker run "${ENV_STR[@]}" --rm --net=host \
        --user="${BUILDER_RUN_USER}" \
-       $VOLUME_MOUNT \
+       "${VOLUME_MOUNT[@]}" \
        -v "$(pwd)":/go/src/github.com/openshift/console \
        --shm-size=512m \
        -w /go/src/github.com/openshift/console \
-       $BUILDER_IMAGE "$@"
+       "$BUILDER_IMAGE" "$@"
