@@ -1,17 +1,12 @@
 import * as _ from 'lodash';
 import * as models from './models';
-import {
-  CAPACITY_USAGE_QUERIES,
-  STORAGE_HEALTH_QUERIES,
-  StorageDashboardQuery,
-} from './constants/queries';
+import { CAPACITY_USAGE_QUERIES, StorageDashboardQuery } from './constants/queries';
 import {
   ClusterServiceVersionAction,
   DashboardsCard,
-  DashboardsOverviewHealthPrometheusSubsystem,
+  DashboardsOverviewHealthResourceSubsystem,
   DashboardsOverviewUtilizationItem,
   DashboardsTab,
-  FeatureFlag,
   KebabActions,
   ModelDefinition,
   ModelFeatureFlag,
@@ -19,14 +14,16 @@ import {
   ResourceTabPage,
   RoutePage,
   ResourceDetailsPage,
-  ActionFeatureFlag,
   DashboardsOverviewResourceActivity,
+  CustomFeatureFlag,
 } from '@console/plugin-sdk';
 import {
+  detectOCS,
+  detectOCSSupportedFeatures,
+  CEPH_FLAG,
   OCS_INDEPENDENT_FLAG,
-  detectIndependentMode,
-  detectOCSVersion45AndAbove,
-  OCS_VERSION_4_5_FLAG,
+  OCS_SUPPORT_FLAGS,
+  OCS_CONVERGED_FLAG,
 } from './features';
 import { ClusterServiceVersionModel } from '@console/operator-lifecycle-manager/src/models';
 import { GridPosition } from '@console/shared/src/components/dashboard/DashboardGrid';
@@ -35,27 +32,25 @@ import { referenceForModel, referenceFor } from '@console/internal/module/k8s';
 import { PersistentVolumeClaimModel } from '@console/internal/models';
 import { getCephHealthState } from './components/dashboard-page/storage-dashboard/status-card/utils';
 import { isClusterExpandActivity } from './components/dashboard-page/storage-dashboard/activity-card/cluster-expand-activity';
+import { WatchCephResource } from './types';
 
 type ConsumedExtensions =
   | ModelFeatureFlag
   | ModelDefinition
   | DashboardsTab
   | DashboardsCard
-  | DashboardsOverviewHealthPrometheusSubsystem
+  | DashboardsOverviewHealthResourceSubsystem<WatchCephResource>
   | DashboardsOverviewUtilizationItem
   | RoutePage
-  | ActionFeatureFlag
+  | CustomFeatureFlag
   | ClusterServiceVersionAction
   | KebabActions
   | ResourceDetailsPage
   | ResourceTabPage
   | ClusterServiceVersionAction
   | KebabActions
-  | FeatureFlag
   | DashboardsOverviewResourceActivity;
 
-const CEPH_FLAG = 'CEPH';
-
 const apiObjectRef = referenceForModel(models.OCSServiceModel);
 
 const plugin: Plugin<ConsumedExtensions> = [
@@ -73,10 +68,15 @@ const plugin: Plugin<ConsumedExtensions> = [
     },
   },
   {
-    type: 'FeatureFlag/Action',
+    type: 'FeatureFlag/Custom',
     properties: {
-      flag: OCS_VERSION_4_5_FLAG,
-      detect: detectOCSVersion45AndAbove,
+      detect: detectOCSSupportedFeatures,
+    },
+  },
+  {
+    type: 'FeatureFlag/Custom',
+    properties: {
+      detect: detectOCS,
     },
   },
   {
@@ -91,7 +91,7 @@ const plugin: Plugin<ConsumedExtensions> = [
         ) /* webpackChunkName: "ceph-storage-volume-snapshot" */,
     },
     flags: {
-      required: [OCS_VERSION_4_5_FLAG, CEPH_FLAG],
+      required: [OCS_SUPPORT_FLAGS.SNAPSHOT, CEPH_FLAG],
     },
   },
   {
@@ -99,8 +99,10 @@ const plugin: Plugin<ConsumedExtensions> = [
     properties: {
       id: 'persistent-storage',
       title: 'Persistent Storage',
-      required: CEPH_FLAG,
-      disallowed: OCS_INDEPENDENT_FLAG,
+    },
+    flags: {
+      required: [OCS_CONVERGED_FLAG],
+      disallowed: [OCS_INDEPENDENT_FLAG],
     },
   },
   {
@@ -112,7 +114,6 @@ const plugin: Plugin<ConsumedExtensions> = [
         import('./components/ocs-install/install-page' /* webpackChunkName: "install-page" */).then(
           (m) => m.default,
         ),
-      required: CEPH_FLAG,
     },
   },
   // Ceph Storage Dashboard Left cards
@@ -125,7 +126,9 @@ const plugin: Plugin<ConsumedExtensions> = [
         import(
           './components/dashboard-page/storage-dashboard/details-card' /* webpackChunkName: "ceph-storage-details-card" */
         ).then((m) => m.default),
-      required: CEPH_FLAG,
+    },
+    flags: {
+      required: [CEPH_FLAG],
     },
   },
   {
@@ -137,7 +140,9 @@ const plugin: Plugin<ConsumedExtensions> = [
         import(
           './components/dashboard-page/storage-dashboard/inventory-card' /* webpackChunkName: "ceph-storage-inventory-card" */
         ).then((m) => m.default),
-      required: CEPH_FLAG,
+    },
+    flags: {
+      required: [CEPH_FLAG],
     },
   },
   // Ceph Storage Dashboard Main Cards
@@ -150,7 +155,9 @@ const plugin: Plugin<ConsumedExtensions> = [
         import(
           './components/dashboard-page/storage-dashboard/status-card/status-card' /* webpackChunkName: "ceph-storage-status-card" */
         ).then((m) => m.default),
-      required: CEPH_FLAG,
+    },
+    flags: {
+      required: [CEPH_FLAG],
     },
   },
   {
@@ -162,7 +169,9 @@ const plugin: Plugin<ConsumedExtensions> = [
         import(
           './components/dashboard-page/storage-dashboard/capacity-breakdown/capacity-breakdown-card' /* webpackChunkName: "ceph-storage-usage-breakdown-card" */
         ).then((m) => m.default),
-      required: CEPH_FLAG,
+    },
+    flags: {
+      required: [CEPH_FLAG],
     },
   },
   {
@@ -174,7 +183,9 @@ const plugin: Plugin<ConsumedExtensions> = [
         import(
           './components/dashboard-page/storage-dashboard/utilization-card/utilization-card' /* webpackChunkName: "ceph-storage-utilization-card" */
         ).then((m) => m.default),
-      required: CEPH_FLAG,
+    },
+    flags: {
+      required: [CEPH_FLAG],
     },
   },
   // Ceph Storage Dashboard Right Cards
@@ -187,16 +198,26 @@ const plugin: Plugin<ConsumedExtensions> = [
         import(
           './components/dashboard-page/storage-dashboard/activity-card/activity-card' /* webpackChunkName: "ceph-storage-activity-card" */
         ).then((m) => m.ActivityCard),
-      required: CEPH_FLAG,
+    },
+    flags: {
+      required: [CEPH_FLAG],
     },
   },
   {
-    type: 'Dashboards/Overview/Health/Prometheus',
+    type: 'Dashboards/Overview/Health/Resource',
     properties: {
       title: 'Storage',
-      queries: [STORAGE_HEALTH_QUERIES[StorageDashboardQuery.CEPH_STATUS_QUERY]],
+      resources: {
+        ceph: {
+          kind: referenceForModel(models.CephClusterModel),
+          namespaced: false,
+          isList: true,
+        },
+      },
       healthHandler: getCephHealthState,
-      required: CEPH_FLAG,
+    },
+    flags: {
+      required: [CEPH_FLAG],
     },
   },
   {
@@ -205,7 +226,9 @@ const plugin: Plugin<ConsumedExtensions> = [
       id: OverviewQuery.STORAGE_UTILIZATION,
       query: CAPACITY_USAGE_QUERIES[StorageDashboardQuery.CEPH_CAPACITY_USED],
       totalQuery: CAPACITY_USAGE_QUERIES[StorageDashboardQuery.CEPH_CAPACITY_TOTAL],
-      required: CEPH_FLAG,
+    },
+    flags: {
+      required: [CEPH_FLAG],
     },
   },
   {
@@ -224,6 +247,7 @@ const plugin: Plugin<ConsumedExtensions> = [
             throw e;
           });
       },
+      disallowed: [OCS_INDEPENDENT_FLAG],
     },
   },
   // Download External Cluster Metadata
@@ -238,14 +262,7 @@ const plugin: Plugin<ConsumedExtensions> = [
         import(
           './components/converged-credentials/credentials' /* webpackChunkName: "ceph-storage-export-credentials" */
         ).then((m) => m.default({})),
-    },
-  },
-  // Independent mode dashboard
-  {
-    type: 'FeatureFlag/Action',
-    properties: {
-      flag: OCS_INDEPENDENT_FLAG,
-      detect: detectIndependentMode,
+      disallowed: [OCS_INDEPENDENT_FLAG],
     },
   },
   {
@@ -253,7 +270,9 @@ const plugin: Plugin<ConsumedExtensions> = [
     properties: {
       id: 'independent-dashboard',
       title: 'Persistent Storage',
-      required: OCS_INDEPENDENT_FLAG,
+    },
+    flags: {
+      required: [OCS_INDEPENDENT_FLAG],
     },
   },
   // Left Cards
@@ -266,7 +285,9 @@ const plugin: Plugin<ConsumedExtensions> = [
         import(
           './components/independent-dashboard-page/details-card/card' /* webpackChunkName: "indepedent-details-card" */
         ).then((m) => m.default),
-      required: OCS_INDEPENDENT_FLAG,
+    },
+    flags: {
+      required: [OCS_INDEPENDENT_FLAG],
     },
   },
   {
@@ -278,7 +299,9 @@ const plugin: Plugin<ConsumedExtensions> = [
         import(
           './components/dashboard-page/storage-dashboard/inventory-card' /* webpackChunkName: "ceph-storage-inventory-card" */
         ).then((m) => m.default),
-      required: OCS_INDEPENDENT_FLAG,
+    },
+    flags: {
+      required: [OCS_INDEPENDENT_FLAG],
     },
   },
   // Center
@@ -291,7 +314,9 @@ const plugin: Plugin<ConsumedExtensions> = [
         import(
           './components/independent-dashboard-page/status-card/card' /* webpackChunkName: "indepedent-status-card" */
         ).then((m) => m.default),
-      required: OCS_INDEPENDENT_FLAG,
+    },
+    flags: {
+      required: [OCS_INDEPENDENT_FLAG],
     },
   },
   {
@@ -303,7 +328,9 @@ const plugin: Plugin<ConsumedExtensions> = [
         import(
           './components/independent-dashboard-page/breakdown-card/card' /* webpackChunkName: "independent-breakdown-card" */
         ).then((m) => m.default),
-      required: OCS_INDEPENDENT_FLAG,
+    },
+    flags: {
+      required: [OCS_INDEPENDENT_FLAG],
     },
   },
   {
@@ -315,7 +342,9 @@ const plugin: Plugin<ConsumedExtensions> = [
         import(
           './components/independent-dashboard-page/utilization-card/card' /* webpackChunkName: "utilization-card" */
         ).then((m) => m.default),
-      required: OCS_INDEPENDENT_FLAG,
+    },
+    flags: {
+      required: [OCS_INDEPENDENT_FLAG],
     },
   },
   // Right
@@ -328,7 +357,9 @@ const plugin: Plugin<ConsumedExtensions> = [
         import(
           './components/dashboard-page/storage-dashboard/activity-card/activity-card' /* webpackChunkName: "ceph-storage-activity-card" */
         ).then((m) => m.ActivityCard),
-      required: OCS_INDEPENDENT_FLAG,
+    },
+    flags: {
+      required: [OCS_INDEPENDENT_FLAG],
     },
   },
   {
@@ -342,7 +373,7 @@ const plugin: Plugin<ConsumedExtensions> = [
       modelParser: referenceFor,
     },
     flags: {
-      required: [OCS_VERSION_4_5_FLAG, CEPH_FLAG],
+      required: [OCS_SUPPORT_FLAGS.SNAPSHOT, CEPH_FLAG],
     },
   },
   {
@@ -359,7 +390,9 @@ const plugin: Plugin<ConsumedExtensions> = [
         import(
           './components/dashboard-page/storage-dashboard/activity-card/cluster-expand-activity' /* webpackChunkName: "ceph-storage-plugin" */
         ).then((m) => m.ClusterExpandActivity),
-      required: CEPH_FLAG,
+    },
+    flags: {
+      required: [CEPH_FLAG],
     },
   },
 ];
