@@ -1,9 +1,10 @@
 import * as _ from 'lodash';
-import { testedRegistry } from '../plugin-test-utils';
+import { isDashboardsOverviewUtilizationItem } from '@console/plugin-sdk';
+import { testedExtensions } from '../plugin-test-utils';
 
 describe('DashboardsOverviewUtilizationItem', () => {
   it('duplicate ids are not allowed', () => {
-    const items = testedRegistry.getDashboardsOverviewUtilizationItems();
+    const items = testedExtensions.toArray().filter(isDashboardsOverviewUtilizationItem);
     const dedupedItems = _.uniqWith(items, (a, b) => a.properties.id === b.properties.id);
     const duplicateItems = _.difference(items, dedupedItems);
 
