@@ -4,8 +4,8 @@ import { PrometheusHealthHandler, URLHealthHandler } from '@console/plugin-sdk';
 
 export const getFooHealthState: URLHealthHandler<any> = () => ({ state: HealthState.OK });
 
-export const getBarHealthState: PrometheusHealthHandler = (responses = [], errors = [], nodes) => {
-  if (!responses.length || !errors.length || !_.get(nodes, 'loaded')) {
+export const getBarHealthState: PrometheusHealthHandler = (responses, nodes) => {
+  if (!responses[0].response || !_.get(nodes, 'loaded')) {
     return {
       state: HealthState.LOADING,
     };
