@@ -1,5 +1,5 @@
 import { K8sKind } from '@console/internal/module/k8s';
-import { Extension } from './extension';
+import { Extension } from './base';
 
 namespace ExtensionProperties {
   export interface GlobalConfig {
