@@ -1,5 +1,6 @@
 import * as React from 'react';
 import { Link } from 'react-router-dom';
+import { alertActions } from '@console/internal/components/notification-drawer';
 import { Timestamp } from '@console/internal/components/utils/timestamp';
 import { alertURL, Alert } from '@console/internal/components/monitoring';
 import { RedExclamationCircleIcon, YellowExclamationTriangleIcon } from '../../status/icons';
@@ -20,12 +21,7 @@ const getSeverityIcon = (severity: string) => {
   }
 };
 
-export const StatusItem: React.FC<StatusItemProps> = ({
-  Icon,
-  timestamp,
-  message,
-  LinkComponent,
-}) => {
+export const StatusItem: React.FC<StatusItemProps> = ({ Icon, timestamp, message, children }) => {
   return (
     <div className="co-status-card__alert-item">
       <div className="co-status-card__alert-item-icon co-dashboard-icon">
@@ -38,26 +34,26 @@ export const StatusItem: React.FC<StatusItemProps> = ({
           </div>
           <span className="co-status-card__health-item-text co-break-word">{message}</span>
         </div>
-        <div className="co-status-card__alert-item-more">
-          <LinkComponent />
-        </div>
+        {children && <div className="co-status-card__alert-item-more">{children}</div>}
       </div>
     </div>
   );
 };
 
 const AlertItem: React.FC<AlertItemProps> = ({ alert }) => {
-  const LinkComponent = React.useCallback(
-    () => <Link to={alertURL(alert, alert.rule.id)}>View details</Link>,
-    [alert],
-  );
+  const action = alertActions.get(alert.rule.name);
   return (
     <StatusItem
       Icon={getSeverityIcon(getAlertSeverity(alert))}
       timestamp={getAlertTime(alert)}
       message={getAlertDescription(alert) || getAlertMessage(alert)}
-      LinkComponent={LinkComponent}
-    />
+    >
+      {action ? (
+        <Link to={action.path}>{action.text}</Link>
+      ) : (
+        <Link to={alertURL(alert, alert.rule.id)}>View details</Link>
+      )}
+    </StatusItem>
   );
 };
 
@@ -67,7 +63,6 @@ type StatusItemProps = {
   Icon: React.ComponentType<any>;
   timestamp?: string;
   message: string;
-  LinkComponent: React.ComponentType<any>;
 };
 
 type AlertItemProps = {
