@@ -1,8 +1,24 @@
 import * as React from 'react';
+import { chart_color_orange_300 as limitColor } from '@patternfly/react-tokens';
 import { Humanize } from '@console/internal/components/utils/types';
-import { AreaChart, AreaChartStatus } from '@console/internal/components/graphs/area';
+import {
+  AreaChart,
+  AreaChartStatus,
+  chartStatusColors,
+} from '@console/internal/components/graphs/area';
 import { DataPoint } from '@console/internal/components/graphs';
 import { ByteDataTypes } from 'packages/console-shared/src/graph-helper/data-utils';
+import {
+  YellowExclamationTriangleIcon,
+  RedExclamationCircleIcon,
+  ColoredIconProps,
+} from '../../status';
+
+export enum LIMIT_STATE {
+  ERROR = 'ERROR',
+  WARN = 'WARN',
+  OK = 'OK',
+}
 
 const getCurrentData = (
   humanizeValue: Humanize,
@@ -53,11 +69,15 @@ export const MultilineUtilizationItem: React.FC<MultilineUtilizationItemProps> =
 
     const currentValue = current.map((curr, index) => {
       const TopConsumerPopover = TopConsumerPopovers && TopConsumerPopovers[index];
-      return TopConsumerPopover ? <TopConsumerPopover current={curr} /> : <div>{curr}</div>;
+      return TopConsumerPopover ? (
+        <TopConsumerPopover key={queries[index].desc} current={curr} />
+      ) : (
+        <div key={queries[index].desc}>{curr}</div>
+      );
     });
 
     return (
-      <div className="co-utilization-card__item">
+      <div className="co-utilization-card__item" data-test-id="utilization-item">
         <div className="co-utilization-card__item-description">
           <div className="co-utilization-card__item-section-multiline">
             <h4 className="pf-c-title pf-m-md">{title}</h4>
@@ -85,55 +105,123 @@ export const UtilizationItem: React.FC<UtilizationItemProps> = React.memo(
     max = null,
     TopConsumerPopover,
     byteDataType,
+    limit = null,
+    requested = null,
+    setLimitReqState,
   }) => {
-    let current;
+    let current: string;
     if (data.length) {
       const latestData = data[data.length - 1];
       current = humanizeValue(latestData.y).string;
     }
 
-    let humanMax;
-    let chartStatus;
+    let humanMax: string;
+    const chartStyle = [null, null, null];
 
-    let humanAvailable;
+    let humanAvailable: string;
     if (current && max) {
       humanMax = humanizeValue(max).string;
       const percentage = (100 * data[data.length - 1].y) / max;
 
       if (percentage >= 90) {
-        chartStatus = AreaChartStatus.ERROR;
-      } else if (percentage >= 75) {
-        chartStatus = AreaChartStatus.WARNING;
+        chartStyle[0] = { data: { fill: chartStatusColors[AreaChartStatus.ERROR] } };
+      } else if (percentage >= 80) {
+        chartStyle[0] = { data: { fill: chartStatusColors[AreaChartStatus.WARNING] } };
       }
 
       humanAvailable = humanizeValue(max - data[data.length - 1].y).string;
     }
 
+    const chartData = error ? [[]] : [data];
+    if (!error && limit) {
+      chartData.push(limit);
+      chartStyle[1] = { data: { strokeDasharray: '3,3', fillOpacity: 0 } };
+    }
+    if (!error && requested) {
+      chartData.push(requested);
+      chartStyle[2] = {
+        data: {
+          stroke: limitColor.value,
+          strokeDasharray: '3,3',
+          fillOpacity: 0,
+        },
+      };
+    }
+
     const chart = (
       <AreaChart
-        data={error ? [[]] : [data]}
+        data={chartData}
         loading={!error && isLoading}
         query={query}
         xAxis={false}
         humanize={humanizeValue}
         padding={{ top: 13, left: 70, bottom: 0, right: 0 }}
         height={70}
-        chartStatus={chartStatus}
+        chartStyle={chartStyle}
         byteDataType={byteDataType}
       />
     );
 
+    let LimitIcon: React.ComponentType<ColoredIconProps>;
+    let humanLimit: string;
+    let limitState = LIMIT_STATE.OK;
+    let requestedState = LIMIT_STATE.OK;
+
+    if (max) {
+      if (limit && limit.length && requested && requested.length) {
+        humanLimit = humanizeValue(limit[limit.length - 1].y).string;
+        const limitPercentage = (100 * limit[limit.length - 1].y) / max;
+        const reqPercentage = (100 * requested[requested.length - 1].y) / max;
+        if (limitPercentage > 100) {
+          limitState = LIMIT_STATE.ERROR;
+        } else if (limitPercentage >= 75) {
+          limitState = LIMIT_STATE.WARN;
+        }
+        if (reqPercentage > 100) {
+          requestedState = LIMIT_STATE.ERROR;
+        } else if (reqPercentage >= 75) {
+          requestedState = LIMIT_STATE.WARN;
+        }
+        if ([limitState, requestedState].includes(LIMIT_STATE.ERROR)) {
+          LimitIcon = RedExclamationCircleIcon;
+        } else if ([limitState, requestedState].includes(LIMIT_STATE.WARN)) {
+          LimitIcon = YellowExclamationTriangleIcon;
+        }
+        setLimitReqState && setLimitReqState({ limit: limitState, requested: requestedState });
+      }
+    }
+
     return (
-      <div className="co-utilization-card__item">
+      <div className="co-utilization-card__item" data-test-id="utilization-item">
         <div className="co-utilization-card__item-description">
           <div className="co-utilization-card__item-section">
             <h4 className="pf-c-title pf-m-md">{title}</h4>
             {error || (!isLoading && !data.length) ? (
               <div className="text-secondary">Not available</div>
-            ) : TopConsumerPopover ? (
-              <TopConsumerPopover current={current} />
             ) : (
-              current
+              <div>
+                {LimitIcon && <LimitIcon className="co-utilization-card__item-icon" />}
+                {TopConsumerPopover ? (
+                  <TopConsumerPopover
+                    current={current}
+                    max={humanMax}
+                    limit={
+                      limit && limit.length ? humanizeValue(limit[limit.length - 1].y).string : null
+                    }
+                    requested={
+                      requested && requested.length
+                        ? humanizeValue(requested[requested.length - 1].y).string
+                        : null
+                    }
+                    available={humanAvailable}
+                    total={humanMax}
+                    limitState={limitState}
+                    requestedState={requestedState}
+                  />
+                ) : (
+                  current
+                )}
+              </div>
             )}
           </div>
           {!error && (humanAvailable || humanMax) && (
@@ -142,7 +230,8 @@ export const UtilizationItem: React.FC<UtilizationItemProps> = React.memo(
                 {humanAvailable && <span>{humanAvailable} available</span>}
               </span>
               <span className="co-utilization-card__item-text">
-                {humanMax && <span>of {humanMax}</span>}
+                {humanLimit && <span>{humanLimit} total limit</span>}
+                {!humanLimit && humanMax && <span>of {humanMax}</span>}
               </span>
             </div>
           )}
@@ -155,9 +244,16 @@ export const UtilizationItem: React.FC<UtilizationItemProps> = React.memo(
 
 export default UtilizationItem;
 
+export type LimitRequested = {
+  limit: LIMIT_STATE;
+  requested: LIMIT_STATE;
+};
+
 type UtilizationItemProps = {
   title: string;
   data?: DataPoint[];
+  limit?: DataPoint[];
+  requested?: DataPoint[];
   isLoading: boolean;
   humanizeValue: Humanize;
   query: string;
@@ -165,6 +261,7 @@ type UtilizationItemProps = {
   max?: number;
   byteDataType?: ByteDataTypes;
   TopConsumerPopover?: React.ComponentType<TopConsumerPopoverProp>;
+  setLimitReqState?: (state: LimitRequested) => void;
 };
 
 type MultilineUtilizationItemProps = {
@@ -182,6 +279,13 @@ type MultilineUtilizationItemProps = {
 
 export type TopConsumerPopoverProp = {
   current: string;
+  max?: string;
+  limit?: string;
+  available?: string;
+  requested?: string;
+  total?: string;
+  limitState?: LIMIT_STATE;
+  requestedState?: LIMIT_STATE;
 };
 
 export type QueryWithDescription = {
