@@ -2,6 +2,7 @@ export interface FormFooterProps {
   handleSubmit?: () => void;
   handleReset?: () => void;
   handleCancel?: () => void;
+  sticky?: boolean;
   submitLabel?: string;
   resetLabel?: string;
   cancelLabel?: string;
@@ -13,3 +14,9 @@ export interface FormFooterProps {
   infoTitle?: string;
   infoMessage?: string;
 }
+
+export interface ActionGroupWithIconsProps {
+  onSubmit: () => void;
+  onClose: () => void;
+  isDisabled?: boolean;
+}
