@@ -6,9 +6,14 @@ export const getImageForCSVIcon = (icon: CSVIcon | undefined) => {
   return icon ? `data:${icon.mediatype};base64,${icon.base64data}` : operatorLogo;
 };
 
-export const isIconUrl = (s: string): boolean => {
-  const urlRegex = /^\s*data:([a-z]+\/[a-z0-9-+.]+(;[a-z-]+=[a-z0-9-]+)?)?(;base64)?,([a-z0-9!$&',()*+;=\-._~:@/?%\s]*)\s*$/i;
-  return !!s.match(urlRegex);
+export const isIconUrl = (url: string): boolean => {
+  try {
+    // eslint-disable-next-line no-new
+    new URL(url);
+    return true;
+  } catch {
+    return false;
+  }
 };
 
 export const getDefaultOperatorIcon = () => operatorLogo;
