@@ -3,9 +3,11 @@ export * from './utils';
 export * from './pod-utils';
 export * from './pod-ring-utils';
 export * from './resource-utils';
+export * from './transformResourceData';
 export * from './validation';
 export * from './table-utils';
 export * from './storage-utils';
 export * from './useCombineRefs';
 export * from './icon-utils';
 export * from './namespace';
+export * from './label-filter';
