@@ -4,6 +4,8 @@ import { ServiceModel } from '@console/knative-plugin';
 import { UNASSIGNED_KEY } from '../../../const';
 import { DeployImageFormData, GitImportFormData, Resources } from '../../import/import-types';
 import { AppResources } from '../edit-application-types';
+import { healthChecksProbeInitialData } from '../../health-checks/health-checks-probe-utils';
+import { healthChecksData } from '../../health-checks/__tests__/create-health-checks-probe-data';
 
 export const knativeService: K8sResourceKind = {
   apiVersion: `${ServiceModel.apiGroup}/${ServiceModel.apiVersion}`,
@@ -437,6 +439,7 @@ export const gitImportInitialValues: GitImportFormData = {
     triggers: { webhook: true, image: true, config: true },
     strategy: 'Source',
   },
+  healthChecks: healthChecksProbeInitialData,
 };
 
 export const externalImageValues: DeployImageFormData = {
@@ -511,6 +514,7 @@ export const externalImageValues: DeployImageFormData = {
   },
   build: { env: [], triggers: {}, strategy: '' },
   isSearchingForImage: false,
+  healthChecks: healthChecksProbeInitialData,
 };
 
 export const internalImageValues: DeployImageFormData = {
@@ -585,4 +589,89 @@ export const internalImageValues: DeployImageFormData = {
   },
   build: { env: [], triggers: {}, strategy: '' },
   isSearchingForImage: false,
+  healthChecks: healthChecksProbeInitialData,
+};
+
+export const knAppResources: AppResources = {
+  editAppResource: {
+    loaded: true,
+    loadError: '',
+    data: knativeService,
+  },
+  route: {
+    loaded: false,
+    loadError: 'routes.route.openshift.io "greeter" not found',
+    data: {},
+  },
+  buildConfig: {
+    loaded: false,
+    loadError: 'Error: buildconfigs.build.openshift.io "greeter" not found',
+    data: {},
+  },
+  imageStream: {
+    loaded: true,
+    loadError: '',
+    data: [],
+  },
+};
+
+export const knExternalImageValues: DeployImageFormData = {
+  application: { name: '', selectedKey: '#UNASSIGNED_KEY#' },
+  build: { env: [], strategy: '', triggers: {} },
+  deployment: { env: [], replicas: 1, triggers: { image: false } },
+  formType: 'edit',
+  image: { image: {}, name: '', ports: [], status: { metadata: {}, status: '' }, tag: '' },
+  imageStream: { grantAccess: true, image: '', namespace: '', tag: '' },
+  isSearchingForImage: false,
+  isi: { image: {}, name: '', ports: [], status: { metadata: {}, status: '' }, tag: '' },
+  labels: {},
+  limits: {
+    cpu: {
+      defaultLimitUnit: '',
+      defaultRequestUnit: '',
+      limit: '',
+      limitUnit: '',
+      request: '',
+      requestUnit: '',
+    },
+    memory: {
+      defaultLimitUnit: 'Mi',
+      defaultRequestUnit: 'Mi',
+      limit: '',
+      limitUnit: 'Mi',
+      request: '',
+      requestUnit: 'Mi',
+    },
+  },
+  name: 'nationalparks-py',
+  pipeline: { enabled: false },
+  project: { name: 'div' },
+  registry: 'external',
+  resources: Resources.KnativeService,
+  route: {
+    create: true,
+    defaultUnknownPort: 8080,
+    disable: true,
+    hostname: '',
+    path: '',
+    secure: false,
+    targetPort: '',
+    tls: {
+      caCertificate: '',
+      certificate: '',
+      destinationCACertificate: '',
+      insecureEdgeTerminationPolicy: '',
+      privateKey: '',
+      termination: '',
+    },
+    unknownTargetPort: '',
+  },
+  searchTerm: 'openshift/hello-openshift',
+  serverless: { scaling: { concurrencylimit: '', concurrencytarget: '', maxpods: '', minpods: 0 } },
+  healthChecks: healthChecksProbeInitialData,
+};
+
+export const gitImportInitialValuesWithHealthChecksEnabled: GitImportFormData = {
+  ...gitImportInitialValues,
+  healthChecks: healthChecksData,
 };
