@@ -12,6 +12,7 @@ import { DeployImageFormData, FirehoseList, Resources } from './import-types';
 import { createOrUpdateDeployImageResources } from './deployImage-submit-utils';
 import { deployValidationSchema } from './deployImage-validation-utils';
 import DeployImageForm from './DeployImageForm';
+import { healthChecksProbeInitialData } from '../health-checks/health-checks-probe-utils';
 
 export interface DeployImageProps {
   namespace: string;
@@ -95,6 +96,7 @@ const DeployImage: React.FC<Props> = ({
       },
     },
     resources: Resources.Kubernetes,
+    resourceTypesNotValid: contextualSource ? [Resources.KnativeService] : [],
     build: {
       env: [],
       triggers: {
@@ -132,6 +134,7 @@ const DeployImage: React.FC<Props> = ({
         defaultLimitUnit: 'Mi',
       },
     },
+    healthChecks: healthChecksProbeInitialData,
   };
 
   const handleSubmit = (values, actions) => {
