@@ -34,10 +34,13 @@ export const projectNameValidationSchema = yup.object().shape({
 
 export const applicationNameValidationSchema = yup.object().shape({
   selectedKey: yup.string(),
-  name: yup.string().when('selectedKey', {
-    is: CREATE_APPLICATION_KEY,
-    then: yup.string().required('Required'),
-  }),
+  name: yup
+    .string()
+    .max(63, 'Cannot be longer than 63 characters.')
+    .when('selectedKey', {
+      is: CREATE_APPLICATION_KEY,
+      then: yup.string().required('Required'),
+    }),
 });
 
 export const deploymentValidationSchema = yup.object().shape({
@@ -156,8 +159,8 @@ export const limitsValidationSchema = yup.object().shape({
         },
         message: 'CPU request must be less than or equal to limit.',
       }),
-    requestUnit: yup.string('Unit must be millicores or cores.'),
-    limitUnit: yup.string('Unit must be millicores or cores.'),
+    requestUnit: yup.string('Unit must be millicores or cores.').ensure(),
+    limitUnit: yup.string('Unit must be millicores or cores.').ensure(),
     limit: yup
       .number()
       .transform((limit) => (_.isNaN(limit) ? undefined : limit))
