@@ -15,7 +15,7 @@ import { createStepStatus, StepStatus, TaskStatus } from './pipeline-step-utils'
 import './PipelineVisualizationTask.scss';
 
 interface TaskProps {
-  pipelineRun?: string;
+  pipelineRunName?: string;
   name: string;
   loaded?: boolean;
   task?: {
@@ -24,10 +24,12 @@ interface TaskProps {
   status?: TaskStatus;
   namespace: string;
   isPipelineRun: boolean;
+  disableTooltip?: boolean;
+  selected?: boolean;
 }
 
 interface PipelineVisualizationTaskProp {
-  pipelineRun?: string;
+  pipelineRunName?: string;
   namespace: string;
   task: {
     name?: string;
@@ -39,13 +41,17 @@ interface PipelineVisualizationTaskProp {
   };
   taskRun?: string;
   pipelineRunStatus?: string;
+  disableTooltip?: boolean;
+  selected?: boolean;
 }
 
 export const PipelineVisualizationTask: React.FC<PipelineVisualizationTaskProp> = ({
-  pipelineRun,
+  pipelineRunName,
   task,
   namespace,
   pipelineRunStatus,
+  disableTooltip,
+  selected,
 }) => {
   const taskStatus = task.status || {
     duration: '',
@@ -60,6 +66,23 @@ export const PipelineVisualizationTask: React.FC<PipelineVisualizationTaskProp>
       taskStatus.reason = runStatus.Cancelled;
     }
   }
+
+  const taskComponent = (
+    <TaskComponent
+      pipelineRunName={pipelineRunName}
+      name={task.name || ''}
+      namespace={namespace}
+      status={taskStatus}
+      isPipelineRun={!!pipelineRunStatus}
+      disableTooltip={disableTooltip}
+      selected={selected}
+    />
+  );
+
+  if (disableTooltip) {
+    return taskComponent;
+  }
+
   let resources;
   if (task.taskRef.kind === ClusterTaskModel.kind) {
     resources = [
@@ -79,37 +102,45 @@ export const PipelineVisualizationTask: React.FC<PipelineVisualizationTaskProp>
       },
     ];
   }
-  return (
-    <Firehose resources={resources}>
-      <TaskComponent
-        pipelineRun={pipelineRun}
-        name={task.name || ''}
-        namespace={namespace}
-        status={taskStatus}
-        isPipelineRun={!!pipelineRunStatus}
-      />
-    </Firehose>
-  );
+  return <Firehose resources={resources}>{taskComponent}</Firehose>;
 };
 const TaskComponent: React.FC<TaskProps> = ({
-  pipelineRun,
+  pipelineRunName,
   namespace,
   task,
   status,
   name,
   isPipelineRun,
+  disableTooltip,
+  selected,
 }) => {
-  const taskData: K8sResourceKind = task.data;
-  const stepList = _.get(taskData, ['spec', 'steps'], []);
+  const stepList = _.get(task, ['data', 'spec', 'steps'], []);
   const stepStatusList: StepStatus[] = stepList.map((step) => createStepStatus(step, status));
   const showStatusState: boolean = isPipelineRun && !!status && !!status.reason;
   const visualName = name || _.get(task, ['metadata', 'name'], '');
-  const path = pipelineRun
-    ? `${resourcePathFromModel(PipelineRunModel, pipelineRun, namespace)}/logs/${name}`
+  const path = pipelineRunName
+    ? `${resourcePathFromModel(PipelineRunModel, pipelineRunName, namespace)}/logs/${name}`
     : undefined;
-  const visTask = (
-    <>
-      <div className="odc-pipeline-vis-task__connector" />
+
+  let taskPill = (
+    <div className={cx('odc-pipeline-vis-task__content', { 'is-selected': selected })}>
+      <div
+        className={cx('odc-pipeline-vis-task__title-wrapper', {
+          'is-text-center': !isPipelineRun,
+        })}
+      >
+        <div className="odc-pipeline-vis-task__title">{visualName}</div>
+        {showStatusState && <TaskComponentTaskStatus steps={stepStatusList} />}
+      </div>
+      {isPipelineRun && (
+        <div className="odc-pipeline-vis-task__status">
+          {showStatusState && <ColoredStatusIcon status={status.reason} height={18} width={18} />}
+        </div>
+      )}
+    </div>
+  );
+  if (!disableTooltip) {
+    taskPill = (
       <Tooltip
         position="bottom"
         enableFlip={false}
@@ -121,29 +152,18 @@ const TaskComponent: React.FC<TaskProps> = ({
           />
         }
       >
-        <div className="odc-pipeline-vis-task__content">
-          <div
-            className={cx('odc-pipeline-vis-task__title-wrapper', {
-              'is-text-center': !isPipelineRun,
-            })}
-          >
-            <div className="odc-pipeline-vis-task__title">{visualName}</div>
-            {showStatusState && <TaskComponentTaskStatus steps={stepStatusList} />}
-          </div>
-          {isPipelineRun && (
-            <div className="odc-pipeline-vis-task__status">
-              {showStatusState && (
-                <ColoredStatusIcon status={status.reason} height={18} width={18} />
-              )}
-            </div>
-          )}
-        </div>
+        {taskPill}
       </Tooltip>
+    );
+  }
+
+  const visTask = (
+    <>
+      <div className="odc-pipeline-vis-task__connector" />
+      {taskPill}
     </>
   );
   return (
-    <li className={cx('odc-pipeline-vis-task')}>
-      {path ? <Link to={path}>{visTask}</Link> : visTask}
-    </li>
+    <div className="odc-pipeline-vis-task">{path ? <Link to={path}>{visTask}</Link> : visTask}</div>
   );
 };
