@@ -1,7 +1,7 @@
 import * as React from 'react';
 import { Button, Flex, FlexItem, FlexItemModifiers } from '@patternfly/react-core';
 import { warnYAML } from './modals';
-import { DevPreviewBadge } from '@console/shared';
+import { TechPreviewBadge } from '@console/shared';
 import { Pipeline } from '../../../utils/pipeline-augment';
 import { goToYAML } from './utils';
 
@@ -9,12 +9,11 @@ import './PipelineBuilderHeader.scss';
 
 type PipelineBuilderHeaderProps = {
   existingPipeline: Pipeline;
-  formIsDirty: boolean;
   namespace: string;
 };
 
 const PipelineBuilderHeader: React.FC<PipelineBuilderHeaderProps> = (props) => {
-  const { existingPipeline, formIsDirty, namespace } = props;
+  const { existingPipeline, namespace } = props;
 
   return (
     <div className="odc-pipeline-builder-header">
@@ -26,18 +25,14 @@ const PipelineBuilderHeader: React.FC<PipelineBuilderHeaderProps> = (props) => {
           <Button
             variant="link"
             onClick={() => {
-              if (formIsDirty) {
-                warnYAML(() => goToYAML(existingPipeline, namespace));
-              } else {
-                goToYAML(existingPipeline, namespace);
-              }
+              warnYAML(() => goToYAML(existingPipeline, namespace));
             }}
           >
             Edit YAML
           </Button>
         </FlexItem>
         <FlexItem>
-          <DevPreviewBadge />
+          <TechPreviewBadge />
         </FlexItem>
       </Flex>
       <hr />
