@@ -2,17 +2,16 @@ import * as React from 'react';
 import * as _ from 'lodash';
 import { Form, TextInputTypes } from '@patternfly/react-core';
 import { FormikProps, FormikValues } from 'formik';
-import { MultiColumnField, InputField, DropdownField } from '../formik-fields';
-import { FormFooter } from '../form-utils';
+import { MultiColumnField, InputField, DropdownField, FormFooter } from '@console/shared';
 
 enum accessRoles {
   '' = 'Select a role',
   admin = 'Admin',
-  view = 'View',
   edit = 'Edit',
+  view = 'View',
 }
 
-const ProjectAccess: React.FC<FormikProps<FormikValues>> = ({
+const ProjectAccessForm: React.FC<FormikProps<FormikValues>> = ({
   handleSubmit,
   handleReset,
   isSubmitting,
@@ -45,4 +44,4 @@ const ProjectAccess: React.FC<FormikProps<FormikValues>> = ({
   </Form>
 );
 
-export default ProjectAccess;
+export default ProjectAccessForm;
