@@ -1,10 +1,17 @@
 import * as _ from 'lodash';
 import { Node } from '@console/topology';
+import { ServiceModel, addEventSource } from '@console/knative-plugin';
+import { referenceForModel } from '@console/internal/module/k8s';
 import { addResourceMenu, addResourceMenuWithoutCatalog } from '../../../actions/add-resources';
 import { GraphData } from '../topology-types';
 
 export const graphActions = (graphData: GraphData, connectorSource?: Node) => {
-  const resourceMenu = connectorSource ? addResourceMenuWithoutCatalog : addResourceMenu;
+  let resourceMenu = connectorSource ? addResourceMenuWithoutCatalog : addResourceMenu;
+  const isKnativeService =
+    connectorSource?.getData()?.data?.kind === referenceForModel(ServiceModel);
+  if (isKnativeService && graphData.eventSourceEnabled) {
+    resourceMenu = [...addResourceMenuWithoutCatalog, addEventSource];
+  }
   return _.reduce(
     resourceMenu,
     (menuItems, menuItem) => {
