@@ -7,7 +7,13 @@ import {
   chart_color_black_500 as cancelledColor,
 } from '@patternfly/react-tokens';
 import { K8sKind, K8sResourceKind, referenceForModel } from '@console/internal/module/k8s';
-import { ClusterTaskModel, PipelineRunModel, TaskModel } from '../models';
+import {
+  ClusterTaskModel,
+  ClusterTriggerBindingModel,
+  PipelineRunModel,
+  TaskModel,
+  TriggerBindingModel,
+} from '../models';
 import { pipelineRunFilterReducer } from './pipeline-filter-reducer';
 
 interface Metadata {
@@ -67,11 +73,25 @@ export interface Resource {
 
 export interface PipelineResource {
   name: string;
-  type?: string;
-  resourceRef?: {
+  type: string;
+}
+
+type PipelineRunResourceCommonProperties = {
+  name: string;
+};
+export type PipelineRunInlineResourceParam = { name: string; value: string };
+export type PipelineRunInlineResource = PipelineRunResourceCommonProperties & {
+  resourceSpec: {
+    params: PipelineRunInlineResourceParam[];
+    type: string;
+  };
+};
+export type PipelineRunReferenceResource = PipelineRunResourceCommonProperties & {
+  resourceRef: {
     name: string;
   };
-}
+};
+export type PipelineRunResource = PipelineRunReferenceResource | PipelineRunInlineResource;
 
 export interface Runs {
   data?: PipelineRun[];
@@ -81,19 +101,27 @@ export type KeyedRuns = { [key: string]: Runs };
 
 export interface Pipeline extends K8sResourceKind {
   latestRun?: PipelineRun;
-  spec?: {
+  spec: {
     params?: PipelineParam[];
     resources?: PipelineResource[];
+    workspaces?: PipelineWorkspace[];
     tasks: PipelineTask[];
     serviceAccountName?: string;
   };
 }
 
+export type TaskRunKind = { pipelineTaskName?: string } & K8sResourceKind;
+
+export interface TaskRuns {
+  [key: string]: TaskRunKind;
+}
+
 export interface PipelineRun extends K8sResourceKind {
   spec?: {
     pipelineRef?: { name: string };
     params?: PipelineRunParam[];
-    resources?: PipelineResource[];
+    workspaces?: PipelineRunWorkspace[];
+    resources?: PipelineRunResource[];
     serviceAccountName?: string;
     // Odd status value that only appears in a single case - cancelling a pipeline
     status?: 'PipelineRunCancelled';
@@ -105,12 +133,17 @@ export interface PipelineRun extends K8sResourceKind {
     conditions?: Condition[];
     startTime?: string;
     completionTime?: string;
-    taskRuns?: {
-      [key: string]: { pipelineTaskName?: string } & K8sResourceKind;
-    };
+    taskRuns?: TaskRuns;
   };
 }
 
+export type PipelineResourceKind = K8sResourceKind & {
+  spec: {
+    params: { name: string; value: string }[];
+    type: string;
+  };
+};
+
 export interface PipelineResourceTaskParam extends PipelineParam {
   type: string;
 }
@@ -160,6 +193,17 @@ export interface PipelineRunParam extends Param {
   resource?: object;
 }
 
+export interface PipelineWorkspace extends Param {
+  type: string;
+  data?: {
+    [key: string]: string;
+  };
+}
+
+export interface PipelineRunWorkspace extends Param {
+  [key: string]: string;
+}
+
 interface FirehoseResource {
   kind: string;
   namespace?: string;
@@ -345,6 +389,9 @@ export const getTaskStatus = (pipelinerun: PipelineRun, pipeline: Pipeline): Tas
 export const getResourceModelFromTaskKind = (kind: string): K8sKind =>
   kind === ClusterTaskModel.kind ? ClusterTaskModel : TaskModel;
 
+export const getResourceModelFromBindingKind = (kind: string): K8sKind =>
+  kind === ClusterTriggerBindingModel.kind ? ClusterTriggerBindingModel : TriggerBindingModel;
+
 export const getResourceModelFromTask = (task: PipelineTask): K8sKind => {
   const {
     taskRef: { kind },
