@@ -1,12 +1,22 @@
 import * as _ from 'lodash';
 import { formatDuration } from '@console/internal/components/utils/datetime';
-import { K8sResourceKind } from '@console/internal/module/k8s';
+import {
+  ContainerStatus,
+  K8sResourceKind,
+  k8sUpdate,
+  k8sGet,
+  SecretKind,
+  K8sResourceCommon,
+} from '@console/internal/module/k8s';
 import {
   LOG_SOURCE_RESTARTING,
   LOG_SOURCE_WAITING,
   LOG_SOURCE_RUNNING,
   LOG_SOURCE_TERMINATED,
 } from '@console/internal/components/utils';
+import { ServiceAccountModel } from '@console/internal/models';
+import { errorModal } from '@console/internal/components/modals/error-modal';
+import { PIPELINE_SERVICE_ACCOUNT, SecretAnnotationId } from '../components/pipelines/const';
 import {
   getLatestRun,
   Pipeline,
@@ -15,6 +25,8 @@ import {
   PipelineParam,
   PipelineRunParam,
   PipelineTaskRef,
+  PipelineWorkspace,
+  PipelineRunWorkspace,
 } from './pipeline-augment';
 import { pipelineFilterReducer, pipelineRunStatus } from './pipeline-filter-reducer';
 
@@ -28,16 +40,9 @@ interface Resource {
   resource?: string;
   from?: string[];
 }
-
-export interface ContainerStatus {
-  name: string;
-  lastState?: string;
-  state?: {
-    waiting?: Record<string, any>;
-    terminated?: Record<string, any>;
-    running?: Record<string, any>;
-  };
-}
+export type ServiceAccountType = {
+  secrets: { [name: string]: string }[];
+} & K8sResourceCommon;
 
 export interface PipelineVisualizationTaskItem {
   name: string;
@@ -69,6 +74,7 @@ export enum ListFilterId {
   Failed = 'Failed',
   Succeeded = 'Succeeded',
   Cancelled = 'Cancelled',
+  Other = '-',
 }
 
 export const ListFilterLabels = {
@@ -76,6 +82,7 @@ export const ListFilterLabels = {
   [ListFilterId.Failed]: 'Failed',
   [ListFilterId.Succeeded]: 'Complete',
   [ListFilterId.Cancelled]: 'Cancelled',
+  [ListFilterId.Other]: 'Other',
 };
 
 // to be used by both Pipeline and Pipelinerun visualisation
@@ -295,6 +302,42 @@ export const getPipelineRunParams = (pipelineParams: PipelineParam[]): PipelineR
   );
 };
 
+export const getPipelineRunWorkspaces = (
+  pipelineWorkspaces: PipelineWorkspace[],
+): PipelineRunWorkspace[] => {
+  return (
+    pipelineWorkspaces &&
+    pipelineWorkspaces.map((workspace) => ({
+      name: workspace.name,
+      ...workspace.data,
+    }))
+  );
+};
+
+export const calculateRelativeTime = (startTime: string, completionTime?: string) => {
+  const start = new Date(startTime).getTime();
+  const end = completionTime ? new Date(completionTime).getTime() : new Date().getTime();
+  const secondsAgo = (end - start) / 1000;
+  const minutesAgo = secondsAgo / 60;
+  const hoursAgo = minutesAgo / 60;
+
+  if (minutesAgo > 90) {
+    const count = Math.round(hoursAgo);
+    return `about ${count} hours`;
+  }
+  if (minutesAgo > 45) {
+    return 'about an hour';
+  }
+  if (secondsAgo > 90) {
+    const count = Math.round(minutesAgo);
+    return `about ${count} minutes`;
+  }
+  if (secondsAgo > 45) {
+    return 'about a minute';
+  }
+  return 'a few seconds';
+};
+
 export const pipelineRunDuration = (run: PipelineRun): string => {
   const startTime = _.get(run, ['status', 'startTime'], null);
   const completionTime = _.get(run, ['status', 'completionTime'], null);
@@ -303,11 +346,41 @@ export const pipelineRunDuration = (run: PipelineRun): string => {
   if (!startTime || (!completionTime && pipelineRunStatus(run) !== 'Running')) {
     return '-';
   }
-  const start = new Date(startTime).getTime();
+  return calculateRelativeTime(startTime, completionTime);
+};
 
-  // For running pipelines duration must be current time - starttime.
-  const duration = completionTime
-    ? new Date(completionTime).getTime() - start
-    : new Date().getTime() - start;
-  return formatDuration(duration);
+export const updateServiceAccount = (
+  secretName: string,
+  originalServiceAccount: ServiceAccountType,
+): Promise<ServiceAccountType> => {
+  const updatedServiceAccount = _.cloneDeep(originalServiceAccount);
+  updatedServiceAccount.secrets = [...updatedServiceAccount.secrets, { name: secretName }];
+  return k8sUpdate(ServiceAccountModel, updatedServiceAccount);
+};
+
+export const associateServiceAccountToSecret = (secret: SecretKind, namespace: string) => {
+  k8sGet(ServiceAccountModel, PIPELINE_SERVICE_ACCOUNT, namespace)
+    .then((serviceAccount) => {
+      if (_.find(serviceAccount.secrets, (s) => s.name === secret.metadata.name) === undefined) {
+        updateServiceAccount(secret.metadata.name, serviceAccount);
+      }
+    })
+    .catch((err) => {
+      errorModal({ error: err.message });
+    });
+};
+
+type KeyValuePair = {
+  key: string;
+  value: string;
+};
+export const getSecretAnnotations = (annotation: KeyValuePair) => {
+  const annotations = {};
+  const annotationPrefix = 'tekton.dev';
+  if (annotation?.key === SecretAnnotationId.Git) {
+    annotations[`${annotationPrefix}/${SecretAnnotationId.Git}-0`] = annotation?.value;
+  } else if (annotation?.key === SecretAnnotationId.Image) {
+    annotations[`${annotationPrefix}/${SecretAnnotationId.Image}-0`] = annotation?.value;
+  }
+  return annotations;
 };
