@@ -3,12 +3,17 @@ import {
   chart_color_red_300 as knativeEventingColor,
 } from '@patternfly/react-tokens';
 import { K8sKind } from '@console/internal/module/k8s';
-import { KNATIVE_EVENT_SOURCE_APIGROUP, KNATIVE_EVENT_SOURCE_APIGROUP_DEP } from './const';
+import { BadgeType } from '@console/shared/src/components/badges/badge-factory';
+import {
+  KNATIVE_EVENT_SOURCE_APIGROUP,
+  KNATIVE_EVENT_SOURCE_APIGROUP_DEP,
+  KNATIVE_SERVING_APIGROUP,
+} from './const';
 
 const apiVersion = 'v1';
 
 export const ConfigurationModel: K8sKind = {
-  apiGroup: 'serving.knative.dev',
+  apiGroup: KNATIVE_SERVING_APIGROUP,
   apiVersion,
   kind: 'Configuration',
   plural: 'configurations',
@@ -35,8 +40,23 @@ export const KnativeServingModel: K8sKind = {
   color: knativeServingColor.value,
 };
 
+export const KnativeEventingModel: K8sKind = {
+  apiGroup: 'operator.knative.dev',
+  apiVersion: 'v1alpha1',
+  kind: 'KnativeEventing',
+  label: 'Knative Eventing',
+  labelPlural: 'Knative Eventings',
+  plural: 'knativeeventings',
+  id: 'knativeeventing',
+  abbr: 'KE',
+  namespaced: true,
+  crd: true,
+  badge: BadgeType.TECH,
+  color: knativeEventingColor.value,
+};
+
 export const RevisionModel: K8sKind = {
-  apiGroup: 'serving.knative.dev',
+  apiGroup: KNATIVE_SERVING_APIGROUP,
   apiVersion,
   kind: 'Revision',
   label: 'Revision',
@@ -50,7 +70,7 @@ export const RevisionModel: K8sKind = {
 };
 
 export const RouteModel: K8sKind = {
-  apiGroup: 'serving.knative.dev',
+  apiGroup: KNATIVE_SERVING_APIGROUP,
   apiVersion,
   kind: 'Route',
   label: 'Route',
@@ -64,7 +84,7 @@ export const RouteModel: K8sKind = {
 };
 
 export const ServiceModel: K8sKind = {
-  apiGroup: 'serving.knative.dev',
+  apiGroup: KNATIVE_SERVING_APIGROUP,
   apiVersion,
   kind: 'Service',
   label: 'Service',
@@ -91,6 +111,20 @@ export const EventSourceCronJobModel: K8sKind = {
   color: knativeEventingColor.value,
 };
 
+export const EventSourcePingModel: K8sKind = {
+  apiGroup: KNATIVE_EVENT_SOURCE_APIGROUP,
+  apiVersion: 'v1alpha1',
+  kind: 'PingSource',
+  label: 'Ping Source',
+  labelPlural: 'Ping Sources',
+  plural: 'pingsources',
+  id: 'pingsource',
+  abbr: 'PS',
+  namespaced: true,
+  crd: true,
+  color: knativeEventingColor.value,
+};
+
 export const EventSourceContainerModel: K8sKind = {
   apiGroup: KNATIVE_EVENT_SOURCE_APIGROUP_DEP,
   apiVersion: 'v1alpha1',
@@ -146,3 +180,17 @@ export const EventSourceKafkaModel: K8sKind = {
   crd: true,
   color: knativeEventingColor.value,
 };
+
+export const EventSourceSinkBindingModel: K8sKind = {
+  apiGroup: KNATIVE_EVENT_SOURCE_APIGROUP,
+  apiVersion: 'v1alpha1',
+  kind: 'SinkBinding',
+  label: 'SinkBinding',
+  labelPlural: 'SinkBindings',
+  plural: 'sinkbindings',
+  id: 'sinkbindingsource',
+  abbr: 'SBS',
+  namespaced: true,
+  crd: true,
+  color: knativeEventingColor.value,
+};
