@@ -7,8 +7,9 @@ import {
   deleteResource,
   click,
 } from '@console/shared/src/test-utils/utils';
-import * as editCdView from '../views/editCDView';
+import * as editCdView from '../views/dialogs/editCDView';
 import * as virtualMachineView from '../views/virtualMachine.view';
+import { saveButton } from '../views/kubevirtUIResource.view';
 import { VM_CREATE_AND_EDIT_TIMEOUT_SECS, STORAGE_CLASS, NOT_AVAILABLE } from './utils/consts';
 import { selectOptionByOptionValue, getRandStr } from './utils/utils';
 import { VirtualMachine } from './models/virtualMachine';
@@ -39,18 +40,18 @@ describe('KubeVirt VM detail - edit cdroms', () => {
   });
 
   it(
-    'creates new container CD, then removes it',
+    'ID(CNV-3104) creates new container CD, then removes it',
     async () => {
       await vm.navigateToDetail();
       await vm.modalEditCDRoms();
 
       await click(editCdView.cdAddBtn);
-      await click(editCdView.saveButton);
+      await click(saveButton);
       await browser.wait(until.presenceOf(editCdView.diskSummary));
 
       await vm.modalEditCDRoms();
       await click(editCdView.cdDeleteBtn);
-      await click(editCdView.saveButton);
+      await click(saveButton);
       await browser.wait(
         until.textToBePresentInElement(
           virtualMachineView.vmDetailCd(vm.namespace, vm.name),
@@ -62,14 +63,14 @@ describe('KubeVirt VM detail - edit cdroms', () => {
   );
 
   it(
-    'creates two new container CDs, then ejects and changes them to URL, PVC',
+    'ID(CNV-3105) creates two new container CDs, then ejects and changes them to URL, PVC',
     async () => {
       await vm.navigateToDetail();
       await vm.modalEditCDRoms();
 
       await click(editCdView.cdAddBtn);
       await click(editCdView.cdAddBtn);
-      await click(editCdView.saveButton);
+      await click(saveButton);
       await browser.wait(until.presenceOf(editCdView.diskSummary));
 
       await vm.modalEditCDRoms();
@@ -80,7 +81,7 @@ describe('KubeVirt VM detail - edit cdroms', () => {
       await selectOptionByOptionValue(editCdView.cdStorageClassSelect(1), STORAGE_CLASS);
       await selectOptionByOptionValue(editCdView.cdTypeSelect(2), 'pvc');
       await selectOptionByOptionValue(editCdView.cdPVCSelect(2), testDataVolume.metadata.name);
-      await click(editCdView.saveButton);
+      await click(saveButton);
 
       await browser.wait(
         until.textToBePresentInElement(editCdView.diskSummary, testDataVolume.metadata.name),
