@@ -2,6 +2,7 @@ import { InitialStepStateGetter } from './types';
 
 export const getResultInitialState: InitialStepStateGetter = () => ({
   value: {
+    isFatal: null,
     mainError: null,
     errors: [],
     requestResults: [],
@@ -11,4 +12,8 @@ export const getResultInitialState: InitialStepStateGetter = () => ({
   hasAllRequiredFilled: null,
   isValid: null,
   isPending: false,
+  isHidden: false,
+  isCreateDisabled: false,
+  isUpdateDisabled: false,
+  isDeleteDisabled: false,
 });
