@@ -3,24 +3,32 @@ import {
   ChangedCommonData,
   ChangedCommonDataProp,
   CloudInitField,
+  ImportProvidersField,
+  OvirtProviderField,
   VMImportProvider,
   VMSettingsField,
-  VMSettingsFieldType,
+  SettingsFieldType,
   VMWareProviderField,
   VMWizardNetwork,
   VMWizardStorage,
   VMWizardTab,
 } from '../types';
 import { DeviceType } from '../../../constants/vm';
+import { FirehoseResourceEnhanced } from '../../../types/custom';
 
 export enum ActionType {
   Create = 'KubevirtVMWizardExternalCreate',
   Dispose = 'KubevirtVMWiExternalDispose',
+  CreateVM = 'KubevirtVMWiExternalCreateVM',
   UpdateCommonData = 'KubevirtVMWizardExternalUpdateCommonData',
+  SetGoToStep = 'KubevirtVMWizardExternalSetGoToStep',
+  OpenDifficultTabs = 'KubevirtVMWizardExternalOpenDifficultTabs',
   SetVmSettingsFieldValue = 'KubevirtVMWizardExternalSetVmSettingsFieldValue',
-  UpdateVmSettingsProviderField = 'KubevirtVMWizardExternalUpdateVmSettingsProviderField',
+  SetImportProvidersFieldValue = 'KubevirtVMWizardExternalSetImportProvidersFieldValue',
+  UpdateImportProviderField = 'KubevirtVMWizardExternalUpdateImportProviderField',
   SetCloudInitFieldValue = 'KubevirtVMWizardExternalSetCloudInitFieldValue',
   SetTabLocked = 'KubevirtVMWizardExternalSetTabLocked',
+  SetTabHidden = 'KubevirtVMWizardExternalSetTabHidden',
   RemoveNIC = 'KubevirtVMWizardExternalRemoveNIC',
   UpdateNIC = 'KubevirtVMWizardExternalUpdateNIC',
   SetDeviceBootOrder = 'KubevirtVMWizardExternalSetDeviceBootOrder',
@@ -35,11 +43,19 @@ export enum InternalActionType {
   Dispose = 'KubevirtVMWizardDispose',
   Update = 'KubevirtVMWizardUpdate',
   UpdateCommonData = 'KubevirtVMWizardUpdateCommonData',
+  SetExtraWSQueries = 'KubevirtVMWizardSetExtraWSQueries',
+  SetGoToStep = 'KubevirtVMWizardSetGoToStep',
   SetTabValidity = 'KubevirtVMWizardSetTabValidity',
   SetTabLocked = 'KubevirtVMWizardSetTabLocked',
+  SetTabHidden = 'KubevirtVMWizardSetTabHidden',
+  SetTabIsCreateDisabled = 'KubevirtVMWizardSetTabIsCreateDisabled',
+  SetTabIsUpdateDisabled = 'KubevirtVMWizardSetTabIsUpdateDisabled',
+  SetTabIsDeleteDisabled = 'KubevirtVMWizardSetTabIsDeleteDisabled',
   SetVmSettingsFieldValue = 'KubevirtVMWizardSetVmSettingsFieldValue',
-  UpdateVMSettingsProviderField = 'KubevirtVMWizardUpdateVmSettingsProviderField',
-  UpdateVMSettingsProvider = 'KubevirtVMWizardUpdateVmSettingsProvider',
+  SetImportProvidersFieldValue = 'KubevirtVMWizardSetImportProvidersFieldValue',
+  UpdateImportProviderField = 'KubevirtVMWizardUpdateImportProviderField',
+  SetImportProvider = 'KubevirtVMWizardSetImportProvider',
+  UpdateImportProvider = 'KubevirtVMWizardUpdateImportProvider',
   SetCloudInitFieldValue = 'KubevirtVMWizardSetCloudInitFieldValue',
   SetInVmSettings = 'KubevirtVMWizardSetInVmSettings',
   SetInVmSettingsBatch = 'KubevirtVMWizardSetInVmSettingsBatch',
@@ -63,9 +79,18 @@ export type WizardInternalAction = {
     isValid?: boolean;
     isLocked?: boolean;
     isPending?: boolean;
+    isHidden?: boolean;
+    isDisabled?: boolean;
     hasAllRequiredFilled?: boolean;
     path?: string[];
-    key?: VMSettingsField | CloudInitField | VMWareProviderField;
+    key?:
+      | VMSettingsField
+      | CloudInitField
+      | VMWareProviderField
+      | OvirtProviderField
+      | ImportProvidersField;
+    queryKey?: string;
+    wsQueries?: FirehoseResourceEnhanced[];
     provider?: VMImportProvider;
     tab?: VMWizardTab;
     batch?: ActionBatch;
@@ -96,17 +121,17 @@ export type UpdateOptions = {
   prevState: any;
 };
 
-export type VmSettingsValidator = (
-  field: VMSettingsFieldType,
+export type Validator<Field = VMSettingsField> = (
+  field: SettingsFieldType<Field>,
   options: UpdateOptions,
 ) => ValidationObject;
 
-export type VMSettingsValidationConfig = {
+export type ValidationConfig<Field = VMSettingsField> = {
   [key: string]: {
-    detectValueChanges?: ((field, options) => VMSettingsField[]) | VMSettingsField[];
+    detectValueChanges?: ((field, options) => Field[]) | Field[];
     detectCommonDataChanges?:
       | ((field, options) => ChangedCommonDataProp[])
       | ChangedCommonDataProp[];
-    validator: VmSettingsValidator;
+    validator: Validator<Field>;
   };
 };
