@@ -1,8 +1,8 @@
 import { VMWizardTab } from '../types';
-import { getProviders } from '../provider-definitions';
 import { UpdateOptions } from './types';
-import { updateVmSettingsState } from './stateUpdate/vmSettings/vm-settings-tab-state-update';
-import { updateStorageTabState } from './stateUpdate/vmSettings/storage-tab-state-update';
+import { updateImportProvidersState } from './state-update/import-provider-tab-state-update';
+import { updateVmSettingsState } from './state-update/vm-settings-tab-state-update';
+import { updateStorageTabState } from './state-update/storage-tab-state-update';
 import {
   setVmSettingsTabValidity,
   validateVmSettings,
@@ -10,8 +10,14 @@ import {
 import { setNetworksTabValidity, validateNetworks } from './validations/networks-tab-validation';
 import { setStoragesTabValidity, validateStorages } from './validations/storage-tab-validation';
 import { setVirtualHardwareTabValidity } from './validations/virtual-hardware-tab-validation';
+import {
+  setImportProvidersTabValidity,
+  validateImportProviderTab,
+} from './validations/import-providers-tab-validation';
+import { finalizeImportProviderStateUpdate } from './finalize-state-update/import-provider-finalize-state-update';
 
 const UPDATE_TABS = [
+  VMWizardTab.IMPORT_PROVIDERS,
   VMWizardTab.VM_SETTINGS,
   VMWizardTab.NETWORKING,
   VMWizardTab.STORAGE,
@@ -19,23 +25,30 @@ const UPDATE_TABS = [
 ];
 
 const updaterResolver = {
+  [VMWizardTab.IMPORT_PROVIDERS]: updateImportProvidersState,
   [VMWizardTab.VM_SETTINGS]: updateVmSettingsState,
   [VMWizardTab.STORAGE]: updateStorageTabState,
 };
 
 const validateTabResolver = {
+  [VMWizardTab.IMPORT_PROVIDERS]: validateImportProviderTab,
   [VMWizardTab.VM_SETTINGS]: validateVmSettings,
   [VMWizardTab.NETWORKING]: validateNetworks,
   [VMWizardTab.STORAGE]: validateStorages,
 };
 
 const isTabValidResolver = {
+  [VMWizardTab.IMPORT_PROVIDERS]: setImportProvidersTabValidity,
   [VMWizardTab.VM_SETTINGS]: setVmSettingsTabValidity,
   [VMWizardTab.NETWORKING]: setNetworksTabValidity,
   [VMWizardTab.STORAGE]: setStoragesTabValidity,
   [VMWizardTab.ADVANCED_VIRTUAL_HARDWARE]: setVirtualHardwareTabValidity,
 };
 
+const finalizeTabResolver = {
+  [VMWizardTab.IMPORT_PROVIDERS]: finalizeImportProviderStateUpdate,
+};
+
 export const updateAndValidateState = (options: UpdateOptions) => {
   const { prevState, changedCommonData, getState } = options;
 
@@ -58,8 +71,9 @@ export const updateAndValidateState = (options: UpdateOptions) => {
       }
     });
   }
-};
 
-export const cleanup = (options: UpdateOptions) => {
-  getProviders().forEach((provider) => provider.cleanup(options));
+  UPDATE_TABS.forEach((tabKey) => {
+    const finalizer = finalizeTabResolver[tabKey];
+    finalizer && finalizer(options);
+  });
 };
