@@ -1,6 +1,6 @@
 import * as React from 'react';
 import { connect } from 'react-redux';
-import { Firehose } from '@console/internal/components/utils';
+import { Firehose, FirehoseResult } from '@console/internal/components/utils';
 import { createModalLauncher, ModalComponentProps } from '@console/internal/components/factory';
 import {
   NamespaceModel,
@@ -9,15 +9,9 @@ import {
   StorageClassModel,
 } from '@console/internal/models';
 import { iGetCommonData } from '../../selectors/immutable/selectors';
-import {
-  VMWizardProps,
-  VMWizardStorage,
-  VMWizardStorageType,
-  VMWizardStorageWithWrappers,
-} from '../../types';
+import { VMWizardProps, VMWizardStorage, VMWizardStorageType } from '../../types';
 import { vmWizardActions } from '../../redux/actions';
 import { ActionType } from '../../redux/types';
-import { getStoragesWithWrappers } from '../../selectors/selectors';
 import { DiskWrapper } from '../../../../k8s/wrapper/vm/disk-wrapper';
 import { VolumeWrapper } from '../../../../k8s/wrapper/vm/volume-wrapper';
 import { DataVolumeWrapper } from '../../../../k8s/wrapper/vm/data-volume-wrapper';
@@ -26,31 +20,33 @@ import { VM_TEMPLATE_NAME_PARAMETER } from '../../../../constants/vm-templates';
 import { PersistentVolumeClaimWrapper } from '../../../../k8s/wrapper/vm/persistent-volume-claim-wrapper';
 import { TemplateValidations } from '../../../../utils/validations/template/template-validations';
 import { getTemplateValidation } from '../../selectors/template';
+import { ConfigMapKind } from '@console/internal/module/k8s';
+import { toShallowJS } from '../../../../utils/immutable';
+import { getStorages } from '../../selectors/selectors';
 
 const VMWizardStorageModal: React.FC<VMWizardStorageModalProps> = (props) => {
   const {
     storage,
     isCreateTemplate,
-    isEditing,
     namespace: vmNamespace,
     useProjects,
     addUpdateStorage,
     storages,
     templateValidations,
+    storageClassConfigMap,
     ...restProps
   } = props;
-  const {
-    type,
-    diskWrapper = DiskWrapper.EMPTY,
-    volumeWrapper = VolumeWrapper.EMPTY,
-    dataVolumeWrapper,
-    persistentVolumeClaimWrapper,
-    ...storageRest
-  } = storage || {};
+  const { type, disk, volume, dataVolume, persistentVolumeClaim, editConfig } = storage || {};
+  const diskWrapper = new DiskWrapper(disk);
 
-  const filteredStorages = storages.filter(
-    (s) => s && s.diskWrapper.getName() && s.diskWrapper.getName() !== diskWrapper.getName(),
-  );
+  const filteredStorages = storages
+    .map(({ disk: d, dataVolume: dv }) => ({
+      diskWrapper: new DiskWrapper(d),
+      dataVolumeWrapper: dataVolume && new DataVolumeWrapper(dv),
+    }))
+    .filter(
+      (s) => s && s.diskWrapper.getName() && s.diskWrapper.getName() !== diskWrapper.getName(),
+    );
 
   const usedDiskNames: Set<string> = new Set(
     filteredStorages.map(({ diskWrapper: dw }) => dw.getName()),
@@ -58,7 +54,7 @@ const VMWizardStorageModal: React.FC<VMWizardStorageModalProps> = (props) => {
 
   const usedPVCNames: Set<string> = new Set(
     filteredStorages
-      .filter(({ dataVolume }) => dataVolume)
+      .filter(({ dataVolumeWrapper }) => dataVolumeWrapper)
       .map(({ dataVolumeWrapper: dvw }) => dvw.getName()),
   );
 
@@ -87,6 +83,7 @@ const VMWizardStorageModal: React.FC<VMWizardStorageModalProps> = (props) => {
     <Firehose resources={resources}>
       <DiskModal
         {...restProps}
+        storageClassConfigMap={storageClassConfigMap}
         vmName={VM_TEMPLATE_NAME_PARAMETER}
         vmNamespace={vmNamespace}
         namespace={namespace}
@@ -94,16 +91,14 @@ const VMWizardStorageModal: React.FC<VMWizardStorageModalProps> = (props) => {
         usedDiskNames={usedDiskNames}
         usedPVCNames={usedPVCNames}
         templateValidations={templateValidations}
-        disk={diskWrapper}
-        volume={volumeWrapper}
-        dataVolume={dataVolumeWrapper}
-        persistentVolumeClaim={persistentVolumeClaimWrapper}
-        disableSourceChange={[
-          VMWizardStorageType.PROVISION_SOURCE_DISK,
-          VMWizardStorageType.PROVISION_SOURCE_TEMPLATE_DISK,
-        ].includes(type)}
+        disk={new DiskWrapper(disk, true)}
+        volume={new VolumeWrapper(volume, true)}
+        dataVolume={dataVolume && new DataVolumeWrapper(dataVolume, true)}
+        persistentVolumeClaim={
+          persistentVolumeClaim && new PersistentVolumeClaimWrapper(persistentVolumeClaim, true)
+        }
         isCreateTemplate={isCreateTemplate}
-        isEditing={isEditing}
+        editConfig={editConfig}
         onSubmit={(
           resultDiskWrapper,
           resultVolumeWrapper,
@@ -111,22 +106,20 @@ const VMWizardStorageModal: React.FC<VMWizardStorageModalProps> = (props) => {
           resultPersistentVolumeClaim,
         ) => {
           addUpdateStorage({
-            ...storageRest,
+            ...storage,
             type: type || VMWizardStorageType.UI_INPUT,
-            disk: DiskWrapper.mergeWrappers(diskWrapper, resultDiskWrapper).asResource(),
-            volume: VolumeWrapper.mergeWrappers(volumeWrapper, resultVolumeWrapper).asResource(),
+            disk: new DiskWrapper(disk, true).mergeWith(resultDiskWrapper).asResource(),
+            volume: new VolumeWrapper(volume, true).mergeWith(resultVolumeWrapper).asResource(),
             dataVolume:
               resultDataVolumeWrapper &&
-              DataVolumeWrapper.mergeWrappers(
-                dataVolumeWrapper,
-                resultDataVolumeWrapper,
-              ).asResource(),
+              new DataVolumeWrapper(dataVolume, true)
+                .mergeWith(resultDataVolumeWrapper)
+                .asResource(),
             persistentVolumeClaim:
               resultPersistentVolumeClaim &&
-              PersistentVolumeClaimWrapper.mergeWrappers(
-                persistentVolumeClaimWrapper,
-                resultPersistentVolumeClaim,
-              ).asResource(),
+              new PersistentVolumeClaimWrapper(persistentVolumeClaim, true)
+                .mergeWith(resultPersistentVolumeClaim)
+                .asResource(),
           });
           return Promise.resolve();
         }}
@@ -137,11 +130,13 @@ const VMWizardStorageModal: React.FC<VMWizardStorageModalProps> = (props) => {
 
 type VMWizardStorageModalProps = ModalComponentProps & {
   isEditing?: boolean;
-  storage?: VMWizardStorageWithWrappers;
+  storage?: VMWizardStorage;
+  showInitialValidation?: boolean;
   namespace: string;
   useProjects?: boolean;
   isCreateTemplate: boolean;
-  storages: VMWizardStorageWithWrappers[];
+  storageClassConfigMap: FirehoseResult<ConfigMapKind>;
+  storages: VMWizardStorage[];
   addUpdateStorage: (storage: VMWizardStorage) => void;
   templateValidations: TemplateValidations;
 };
@@ -152,7 +147,10 @@ const stateToProps = (state, { wizardReduxID }) => {
     useProjects,
     namespace: iGetCommonData(state, wizardReduxID, VMWizardProps.activeNamespace),
     isCreateTemplate: iGetCommonData(state, wizardReduxID, VMWizardProps.isCreateTemplate),
-    storages: getStoragesWithWrappers(state, wizardReduxID),
+    storageClassConfigMap: toShallowJS(
+      iGetCommonData(state, wizardReduxID, VMWizardProps.storageClassConfigMap),
+    ),
+    storages: getStorages(state, wizardReduxID),
     templateValidations: getTemplateValidation(state, wizardReduxID),
   };
 };
