@@ -1,8 +1,10 @@
+import * as _ from 'lodash';
 import * as React from 'react';
 import { FormSelect, FormSelectOption } from '@patternfly/react-core';
 import { ValidationErrorType, asValidationObject } from '@console/shared/src/utils/validation';
 import {
   concatImmutableLists,
+  iGet,
   iGetIsLoaded,
   iGetLoadedData,
   immutableListToShallowJS,
@@ -17,10 +19,10 @@ import {
 } from '../../../../selectors/vm-template/combined-dependent';
 import { flavorSort, ignoreCaseSort } from '../../../../utils/sort';
 import { VMSettingsField } from '../../types';
-import { iGetFieldValue } from '../../selectors/immutable/vm-settings';
-import { getPlaceholder } from '../../utils/vm-settings-tab-utils';
+import { iGetFieldValue } from '../../selectors/immutable/field';
+import { getPlaceholder } from '../../utils/renderable-field-utils';
 import { nullOnEmptyChange } from '../../utils/utils';
-import { operatingSystemsNative } from '../../native/consts';
+import { operatingSystemsNative } from '../../../../constants/vm-templates/os';
 
 export const OSFlavor: React.FC<OSFlavorProps> = React.memo(
   ({
@@ -35,6 +37,9 @@ export const OSFlavor: React.FC<OSFlavorProps> = React.memo(
   }) => {
     const flavor = iGetFieldValue(flavorField);
     const os = iGetFieldValue(operatinSystemField);
+    const display = iGet(operatinSystemField, 'display');
+    const displayOnly = !!display;
+
     const params = {
       userTemplate,
       flavor,
@@ -46,9 +51,15 @@ export const OSFlavor: React.FC<OSFlavorProps> = React.memo(
       concatImmutableLists(iGetLoadedData(commonTemplates), iGetLoadedData(userTemplates)),
     );
 
-    const operatingSystems = openshiftFlag
-      ? ignoreCaseSort(getOperatingSystems(vanillaTemplates, params), ['name'])
-      : operatingSystemsNative;
+    let operatingSystems;
+
+    if (displayOnly) {
+      operatingSystems = [{ name: display, id: display }];
+    } else {
+      operatingSystems = openshiftFlag
+        ? ignoreCaseSort(getOperatingSystems(vanillaTemplates, params), ['name'])
+        : operatingSystemsNative;
+    }
 
     const flavors = flavorSort(getFlavors(vanillaTemplates, params));
 
@@ -88,12 +99,14 @@ export const OSFlavor: React.FC<OSFlavorProps> = React.memo(
           validation={operatingSystemValidation}
           loadingResources={loadingResources}
         >
-          <FormField>
+          <FormField value={displayOnly ? display : undefined}>
             <FormSelect onChange={nullOnEmptyChange(onChange, VMSettingsField.OPERATING_SYSTEM)}>
-              <FormSelectPlaceholderOption
-                placeholder={getPlaceholder(VMSettingsField.OPERATING_SYSTEM)}
-                isDisabled={!!os}
-              />
+              {!displayOnly && (
+                <FormSelectPlaceholderOption
+                  placeholder={getPlaceholder(VMSettingsField.OPERATING_SYSTEM)}
+                  isDisabled={!!os}
+                />
+              )}
               {operatingSystems.map(({ id, name }) => {
                 return <FormSelectOption key={id} value={id} label={name || id} />;
               })}
@@ -113,7 +126,7 @@ export const OSFlavor: React.FC<OSFlavorProps> = React.memo(
                 isDisabled={!!flavor}
               />
               {flavors.map((f) => {
-                return <FormSelectOption key={f} value={f} label={f} />;
+                return <FormSelectOption key={f} value={f} label={_.capitalize(f)} />;
               })}
             </FormSelect>
           </FormField>
