@@ -1,11 +1,5 @@
 import * as React from 'react';
-import {
-  Checkbox,
-  FormSelect,
-  FormSelectOption,
-  TextArea,
-  TextInput,
-} from '@patternfly/react-core';
+import { Form, FormSelect, FormSelectOption, TextArea, TextInput } from '@patternfly/react-core';
 import { connect } from 'react-redux';
 import { iGet, iGetIn } from '../../../../utils/immutable';
 import { FormFieldMemoRow } from '../../form/form-field-row';
@@ -13,7 +7,6 @@ import { FormField, FormFieldType } from '../../form/form-field';
 import { FormSelectPlaceholderOption } from '../../../form/form-select-placeholder-option';
 import { vmWizardActions } from '../../redux/actions';
 import {
-  VMImportProvider,
   VMSettingsField,
   VMSettingsRenderableField,
   VMWizardProps,
@@ -21,19 +14,17 @@ import {
 } from '../../types';
 import { iGetVmSettings } from '../../selectors/immutable/vm-settings';
 import { ActionType } from '../../redux/types';
-import { getFieldId, getPlaceholder } from '../../utils/vm-settings-tab-utils';
+import { getPlaceholder } from '../../utils/renderable-field-utils';
 import { iGetCommonData } from '../../selectors/immutable/selectors';
-import { FormFieldForm } from '../../form/form-field-form';
 import { iGetProvisionSourceStorage } from '../../selectors/immutable/storage';
-import { ProvisionSource } from '../../../../constants/vm/provision-source';
 import { WorkloadProfile } from './workload-profile';
 import { OSFlavor } from './os-flavor';
 import { UserTemplates } from './user-templates';
 import { MemoryCPU } from './memory-cpu';
 import { ContainerSource } from './container-source';
 import { URLSource } from './url-source';
-import { VMWareImportProvider } from './providers/vmware-import-provider/vmware-import-provider';
 
+import '../../create-vm-wizard-footer.scss';
 import './vm-settings-tab.scss';
 
 export class VMSettingsTabComponent extends React.Component<VMSettingsTabComponentProps> {
@@ -48,54 +39,44 @@ export class VMSettingsTabComponent extends React.Component<VMSettingsTabCompone
 
   render() {
     const {
+      userTemplateName,
       userTemplates,
       commonTemplates,
       provisionSourceStorage,
       updateStorage,
-      isReview,
-      wizardReduxID,
       openshiftFlag,
     } = this.props;
 
     return (
-      <FormFieldForm isReview={isReview}>
+      <Form className="co-m-pane__body co-m-pane__form kubevirt-create-vm-modal__form">
         <FormFieldMemoRow
-          key={VMSettingsField.PROVIDER}
-          field={this.getField(VMSettingsField.PROVIDER)}
-          fieldType={FormFieldType.SELECT}
+          field={this.getField(VMSettingsField.NAME)}
+          fieldType={FormFieldType.TEXT}
         >
           <FormField>
-            <FormSelect onChange={this.onChange(VMSettingsField.PROVIDER)}>
-              <FormSelectPlaceholderOption
-                placeholder={getPlaceholder(VMSettingsField.PROVIDER)}
-                isDisabled={!!this.getFieldValue(VMSettingsField.PROVIDER)}
-              />
-              {(this.getFieldAttribute(VMSettingsField.PROVIDER, 'providers') || []).map(
-                (provider) => (
-                  <FormSelectOption key={provider} value={provider} label={provider} />
-                ),
-              )}
-            </FormSelect>
+            <TextInput onChange={this.onChange(VMSettingsField.NAME)} />
           </FormField>
         </FormFieldMemoRow>
-        {ProvisionSource.fromString(this.getFieldValue(VMSettingsField.PROVISION_SOURCE_TYPE)) ===
-          ProvisionSource.IMPORT && (
-          <>
-            <VMWareImportProvider key={VMImportProvider.VMWARE} wizardReduxID={wizardReduxID} />
-          </>
-        )}
-        {!isReview && (
-          <UserTemplates
-            key={VMSettingsField.USER_TEMPLATE}
-            userTemplateField={this.getField(VMSettingsField.USER_TEMPLATE)}
-            userTemplates={userTemplates}
-            commonTemplates={commonTemplates}
-            openshiftFlag={openshiftFlag}
-            onChange={this.props.onFieldChange}
-          />
-        )}
         <FormFieldMemoRow
-          key={VMSettingsField.PROVISION_SOURCE_TYPE}
+          field={this.getField(VMSettingsField.DESCRIPTION)}
+          fieldType={FormFieldType.TEXT_AREA}
+        >
+          <FormField>
+            <TextArea
+              onChange={this.onChange(VMSettingsField.DESCRIPTION)}
+              className="kubevirt-create-vm-modal__description"
+            />
+          </FormField>
+        </FormFieldMemoRow>
+        <UserTemplates
+          userTemplateField={this.getField(VMSettingsField.USER_TEMPLATE)}
+          forceSingleUserTemplateName={userTemplateName}
+          userTemplates={userTemplates}
+          commonTemplates={commonTemplates}
+          openshiftFlag={openshiftFlag}
+          onChange={this.props.onFieldChange}
+        />
+        <FormFieldMemoRow
           field={this.getField(VMSettingsField.PROVISION_SOURCE_TYPE)}
           fieldType={FormFieldType.SELECT}
         >
@@ -137,7 +118,6 @@ export class VMSettingsTabComponent extends React.Component<VMSettingsTabCompone
           memoryField={this.getField(VMSettingsField.MEMORY)}
           cpuField={this.getField(VMSettingsField.CPU)}
           onChange={this.props.onFieldChange}
-          isReview={isReview}
         />
         <WorkloadProfile
           userTemplates={userTemplates}
@@ -148,39 +128,7 @@ export class VMSettingsTabComponent extends React.Component<VMSettingsTabCompone
           flavor={this.getFieldValue(VMSettingsField.FLAVOR)}
           onChange={this.props.onFieldChange}
         />
-
-        <FormFieldMemoRow
-          field={this.getField(VMSettingsField.NAME)}
-          fieldType={FormFieldType.TEXT}
-        >
-          <FormField>
-            <TextInput onChange={this.onChange(VMSettingsField.NAME)} />
-          </FormField>
-        </FormFieldMemoRow>
-        <FormFieldMemoRow
-          field={this.getField(VMSettingsField.DESCRIPTION)}
-          fieldType={FormFieldType.TEXT_AREA}
-        >
-          <FormField>
-            <TextArea
-              onChange={this.onChange(VMSettingsField.DESCRIPTION)}
-              className="kubevirt-create-vm-modal__description"
-            />
-          </FormField>
-        </FormFieldMemoRow>
-        <FormFieldMemoRow
-          field={this.getField(VMSettingsField.START_VM)}
-          fieldType={FormFieldType.INLINE_CHECKBOX}
-        >
-          <FormField>
-            <Checkbox
-              className="kubevirt-create-vm-modal__start_vm_checkbox"
-              id={getFieldId(VMSettingsField.START_VM)}
-              onChange={this.onChange(VMSettingsField.START_VM)}
-            />
-          </FormField>
-        </FormFieldMemoRow>
-      </FormFieldForm>
+      </Form>
     );
   }
 }
@@ -188,6 +136,7 @@ export class VMSettingsTabComponent extends React.Component<VMSettingsTabCompone
 const stateToProps = (state, { wizardReduxID }) => ({
   vmSettings: iGetVmSettings(state, wizardReduxID),
   commonTemplates: iGetCommonData(state, wizardReduxID, VMWizardProps.commonTemplates),
+  userTemplateName: iGetCommonData(state, wizardReduxID, VMWizardProps.userTemplateName),
   userTemplates: iGetCommonData(state, wizardReduxID, VMWizardProps.userTemplates),
   openshiftFlag: iGetCommonData(state, wizardReduxID, VMWizardProps.openshiftFlag),
   provisionSourceStorage: iGetProvisionSourceStorage(state, wizardReduxID),
@@ -199,8 +148,8 @@ type VMSettingsTabComponentProps = {
   vmSettings: any;
   provisionSourceStorage: VMWizardStorage;
   commonTemplates: any;
+  userTemplateName: string;
   userTemplates: any;
-  isReview: boolean;
   openshiftFlag: boolean;
   wizardReduxID: string;
 };
