@@ -11,7 +11,7 @@ import {
   StorageClassModel,
 } from '@console/internal/models';
 import { getLoadedData } from '../../../utils';
-import { asVM, getVMLikeModel } from '../../../selectors/vm';
+import { getVMLikeModel } from '../../../selectors/vm';
 import { VMLikeEntityKind } from '../../../types/vmLike';
 import { DiskWrapper } from '../../../k8s/wrapper/vm/disk-wrapper';
 import { VolumeWrapper } from '../../../k8s/wrapper/vm/volume-wrapper';
@@ -20,18 +20,19 @@ import { getUpdateDiskPatches } from '../../../k8s/patches/vm/vm-disk-patches';
 import { CombinedDiskFactory } from '../../../k8s/wrapper/vm/combined-disk';
 import { DiskModal } from './disk-modal';
 import { TemplateValidations } from '../../../utils/validations/template/template-validations';
+import { V1Disk } from '../../../types/vm/disk/V1Disk';
+import { V1Volume } from '../../../types/vm/disk/V1Volume';
+import { V1alpha1DataVolume } from '../../../types/vm/disk/V1alpha1DataVolume';
+import { useStorageClassConfigMapWrapped } from '../../../hooks/storage-class-config-map';
 
 const DiskModalFirehoseComponent: React.FC<DiskModalFirehoseComponentProps> = (props) => {
   const { disk, volume, dataVolume, vmLikeEntity, vmLikeEntityLoading, ...restProps } = props;
 
   const vmLikeFinal = getLoadedData(vmLikeEntityLoading, vmLikeEntity); // default old snapshot before loading a new one
-  const vm = asVM(vmLikeFinal);
 
-  const diskWrapper = disk ? DiskWrapper.initialize(disk) : DiskWrapper.EMPTY;
-  const volumeWrapper = volume ? VolumeWrapper.initialize(volume) : VolumeWrapper.EMPTY;
-  const dataVolumeWrapper = dataVolume
-    ? DataVolumeWrapper.initialize(dataVolume)
-    : DataVolumeWrapper.EMPTY;
+  const diskWrapper = new DiskWrapper(disk);
+  const volumeWrapper = new VolumeWrapper(volume);
+  const dataVolumeWrapper = new DataVolumeWrapper(dataVolume);
 
   const combinedDiskFactory = CombinedDiskFactory.initializeFromVMLikeEntity(vmLikeFinal);
 
@@ -39,37 +40,40 @@ const DiskModalFirehoseComponent: React.FC<DiskModalFirehoseComponentProps> = (p
     k8sPatch(
       getVMLikeModel(vmLikeEntity),
       vmLikeEntity,
-      await getUpdateDiskPatches(vmLikeEntity, {
-        disk: DiskWrapper.mergeWrappers(diskWrapper, resultDisk).asResource(),
-        volume: VolumeWrapper.mergeWrappers(volumeWrapper, resultVolume).asResource(),
+      getUpdateDiskPatches(vmLikeEntity, {
+        disk: new DiskWrapper(diskWrapper, true).mergeWith(resultDisk).asResource(),
+        volume: new VolumeWrapper(volumeWrapper, true).mergeWith(resultVolume).asResource(),
         dataVolume:
           resultDataVolume &&
-          DataVolumeWrapper.mergeWrappers(dataVolumeWrapper, resultDataVolume).asResource(),
+          new DataVolumeWrapper(dataVolume, true).mergeWith(resultDataVolume).asResource(),
         oldDiskName: diskWrapper.getName(),
         oldVolumeName: volumeWrapper.getName(),
         oldDataVolumeName: dataVolumeWrapper.getName(),
       }),
     );
 
+  const storageClassConfigMap = useStorageClassConfigMapWrapped();
+
   return (
     <DiskModal
       {...restProps}
+      storageClassConfigMap={storageClassConfigMap}
       usedDiskNames={combinedDiskFactory.getUsedDiskNames(diskWrapper.getName())}
       usedPVCNames={combinedDiskFactory.getUsedDataVolumeNames(dataVolumeWrapper.getName())}
-      vmName={getName(vm)}
-      vmNamespace={getNamespace(vm)}
-      disk={diskWrapper}
-      volume={volumeWrapper}
-      dataVolume={dataVolumeWrapper}
+      vmName={getName(vmLikeFinal)}
+      vmNamespace={getNamespace(vmLikeFinal)}
+      disk={new DiskWrapper(diskWrapper, true)}
+      volume={new VolumeWrapper(volumeWrapper, true)}
+      dataVolume={new DataVolumeWrapper(dataVolumeWrapper, true)}
       onSubmit={onSubmit}
     />
   );
 };
 
 type DiskModalFirehoseComponentProps = ModalComponentProps & {
-  disk?: any;
-  volume?: any;
-  dataVolume?: any;
+  disk?: V1Disk;
+  volume?: V1Volume;
+  dataVolume?: V1alpha1DataVolume;
   isEditing?: boolean;
   namespace: string;
   onNamespaceChanged: (namespace: string) => void;
