@@ -6,27 +6,21 @@ import {
   FormSelect,
   FormSelectOption,
   TextInput,
+  Expandable,
 } from '@patternfly/react-core';
 import {
   FirehoseResult,
   HandlePromiseProps,
-  validate,
   withHandlePromise,
 } from '@console/internal/components/utils';
-import {
-  createModalLauncher,
-  ModalBody,
-  ModalComponentProps,
-  ModalTitle,
-} from '@console/internal/components/factory';
-import { K8sResourceKind } from '@console/internal/module/k8s';
+import { ModalBody, ModalComponentProps, ModalTitle } from '@console/internal/components/factory';
 import {
   NamespaceModel,
   PersistentVolumeClaimModel,
   StorageClassModel,
 } from '@console/internal/models';
 import { getName } from '@console/shared/src';
-import { getLoadedData, prefixedID } from '../../../utils';
+import { getLoadedData, isLoaded, prefixedID } from '../../../utils';
 import { validateDisk } from '../../../utils/validations/vm';
 import { isValidationError } from '../../../utils/validations/common';
 import { FormRow } from '../../form/form-row';
@@ -34,6 +28,10 @@ import {
   asFormSelectValue,
   FormSelectPlaceholderOption,
 } from '../../form/form-select-placeholder-option';
+import {
+  getDefaultSCAccessModes,
+  getDefaultSCVolumeMode,
+} from '../../../selectors/config-map/sc-defaults';
 import {
   ADD,
   DYNAMIC,
@@ -47,18 +45,24 @@ import { useShowErrorToggler } from '../../../hooks/use-show-error-toggler';
 import { DiskWrapper } from '../../../k8s/wrapper/vm/disk-wrapper';
 import { DataVolumeWrapper } from '../../../k8s/wrapper/vm/data-volume-wrapper';
 import { VolumeWrapper } from '../../../k8s/wrapper/vm/volume-wrapper';
-import { DiskBus, DiskType } from '../../../constants/vm/storage';
+import { AccessMode, DiskBus, DiskType, VolumeMode } from '../../../constants/vm/storage';
 import { getPvcStorageSize } from '../../../selectors/pvc/selectors';
 import { K8sResourceSelectRow } from '../../form/k8s-resource-select-row';
 import { SizeUnitFormRow } from '../../form/size-unit-form-row';
 import { CombinedDisk } from '../../../k8s/wrapper/vm/combined-disk';
 import { PersistentVolumeClaimWrapper } from '../../../k8s/wrapper/vm/persistent-volume-claim-wrapper';
-import { BinaryUnit } from '../../form/size-unit-utils';
+import { BinaryUnit, stringValueUnitSplit } from '../../form/size-unit-utils';
 import { StorageUISource } from './storage-ui-source';
 import { TemplateValidations } from '../../../utils/validations/template/template-validations';
+import { ConfigMapKind } from '@console/internal/module/k8s';
+import { UIStorageEditConfig } from '../../../types/ui/storage';
+import { isFieldDisabled } from '../../../utils/ui/edit-config';
+
+import './disk-modal.scss';
 
 export const DiskModal = withHandlePromise((props: DiskModalProps) => {
   const {
+    showInitialValidation,
     storageClasses,
     usedPVCNames,
     persistentVolumeClaims,
@@ -68,22 +72,30 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
     namespaces,
     onNamespaceChanged,
     usedDiskNames,
-    disableSourceChange,
     isCreateTemplate,
     onSubmit,
-    inProgress,
+    inProgress: _inProgress,
     isEditing,
     errorMessage,
     handlePromise,
     close,
     cancel,
     templateValidations,
+    storageClassConfigMap: _storageClassConfigMap,
+    editConfig,
   } = props;
+  const inProgress = _inProgress || !isLoaded(_storageClassConfigMap);
+  const isDisabled = (fieldName: string, disabled?: boolean) =>
+    inProgress || disabled || isFieldDisabled(editConfig, fieldName);
+
+  const storageClassConfigMap = getLoadedData(_storageClassConfigMap);
+
   const asId = prefixedID.bind(null, 'disk');
-  const disk = props.disk || DiskWrapper.EMPTY;
-  const volume = props.volume || VolumeWrapper.EMPTY;
-  const dataVolume = props.dataVolume || DataVolumeWrapper.EMPTY;
+  const disk = props.disk || new DiskWrapper();
+  const volume = props.volume || new VolumeWrapper();
+  const dataVolume = props.dataVolume || new DataVolumeWrapper();
   const tValidations = templateValidations || new TemplateValidations();
+
   const validAllowedBuses = tValidations.getAllowedBuses(disk.getType());
   const recommendedBuses = tValidations.getRecommendedBuses(disk.getType());
 
@@ -102,13 +114,13 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
     combinedDisk.getInitialSource(isEditing),
   );
 
-  const [url, setURL] = React.useState<string>(dataVolume.getURL);
+  const [url, setURL] = React.useState<string>(dataVolume.getURL());
 
   const [containerImage, setContainerImage] = React.useState<string>(
     volume.getContainerImage() || '',
   );
 
-  const [pvcName, setPVCName] = React.useState<string>(combinedDisk.getPVCName(source));
+  const [pvcName, setPVCName] = React.useState<string>(combinedDisk.getPVCNameBySource(source));
 
   const [name, setName] = React.useState<string>(
     disk.getName() || getSequenceName('disk', usedDiskNames),
@@ -122,7 +134,7 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
         : [...validAllowedBuses][0]),
   );
   const [storageClassName, setStorageClassName] = React.useState<string>(
-    combinedDisk.getStorageClassName(),
+    combinedDisk.getStorageClassName() || '',
   );
 
   const [size, setSize] = React.useState<string>(
@@ -132,6 +144,28 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
     (combinedDiskSize && combinedDiskSize.unit) || BinaryUnit.Gi,
   );
 
+  const [advancedDrawerIsOpen, setAdvancedDrawerIsOpen] = React.useState(false);
+
+  const [accessMode, setAccessMode] = React.useState<AccessMode>(
+    (isEditing && (combinedDisk.getAccessModes() || [])[0]) || null,
+  );
+
+  const [volumeMode, setVolumeMode] = React.useState<VolumeMode>(
+    (isEditing && combinedDisk.getVolumeMode()) || null,
+  );
+
+  React.useEffect(() => {
+    if (!isEditing && isLoaded(_storageClassConfigMap)) {
+      if (source.requiresVolumeMode()) {
+        setVolumeMode(getDefaultSCVolumeMode(storageClassConfigMap));
+      }
+      if (source.requiresAccessModes()) {
+        setAccessMode(getDefaultSCAccessModes(storageClassConfigMap)[0]);
+      }
+    }
+    // eslint-disable-next-line react-hooks/exhaustive-deps
+  }, [isLoaded(_storageClassConfigMap)]);
+
   const resultDisk = DiskWrapper.initializeFromSimpleData({
     name,
     bus,
@@ -139,46 +173,42 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
   });
 
   const resultDataVolumeName = prefixedID(vmName, name);
-  let resultVolume;
-  if (source.requiresVolume()) {
-    // update just Disk for unknown sources
-    resultVolume = VolumeWrapper.initializeFromSimpleData(
-      {
-        name,
-        type: source.getVolumeType(),
-        typeData: {
-          name: resultDataVolumeName,
-          claimName: pvcName,
-          image: containerImage,
-        },
-      },
-      { sanitizeTypeData: true },
-    );
-  }
+
+  const resultVolume = VolumeWrapper.initializeFromSimpleData({
+    name,
+    type: source.getVolumeType(),
+    typeData: {
+      name: resultDataVolumeName,
+      claimName: pvcName,
+      image: containerImage,
+    },
+  });
 
   let resultDataVolume;
   if (source.requiresDatavolume()) {
-    resultDataVolume = DataVolumeWrapper.initializeFromSimpleData(
-      {
-        name: resultDataVolumeName,
-        storageClassName,
-        type: source.getDataVolumeSourceType(),
-        size,
-        unit,
-        typeData: { name: pvcName, namespace, url },
-      },
-      { sanitizeTypeData: true },
-    );
+    resultDataVolume = DataVolumeWrapper.initializeFromSimpleData({
+      name: resultDataVolumeName,
+      storageClassName: storageClassName || null, // || null is to enable merging
+      type: source.getDataVolumeSourceType(),
+      size,
+      unit,
+      typeData: { name: pvcName, namespace, url },
+    })
+      .setVolumeMode(volumeMode || null)
+      .setAccessModes(accessMode ? [accessMode] : null);
   }
 
   let resultPersistentVolumeClaim;
   if (source.requiresNewPVC()) {
-    resultPersistentVolumeClaim = PersistentVolumeClaimWrapper.initializeFromSimpleData({
-      name,
-      storageClassName,
-      size,
-      unit,
-    });
+    resultPersistentVolumeClaim = new PersistentVolumeClaimWrapper()
+      .init({
+        name,
+        storageClassName: storageClassName || null, // || null is to enable merging
+        size,
+        unit,
+      })
+      .setVolumeMode(volumeMode || null)
+      .setAccessModes(accessMode ? [accessMode] : null);
   }
 
   const {
@@ -198,7 +228,11 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
     templateValidations,
   });
 
-  const [showUIError, setShowUIError] = useShowErrorToggler(false, isValid, isValid);
+  const [showUIError, setShowUIError] = useShowErrorToggler(
+    !!showInitialValidation,
+    isValid,
+    isValid,
+  );
 
   const submit = (e) => {
     e.preventDefault();
@@ -223,16 +257,31 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
     [setName, setPVCName, source],
   );
 
-  const onSourceChanged = (uiSource) => {
-    if (disableSourceChange) {
-      return;
+  const onStorageClassNameChanged = (newStorageClassName) => {
+    // eslint-disable-next-line eqeqeq
+    if (newStorageClassName != storageClassName) {
+      setStorageClassName(newStorageClassName);
+      const newAccessMode = getDefaultSCAccessModes(storageClassConfigMap, newStorageClassName)[0];
+      const newVolumeMode = getDefaultSCVolumeMode(storageClassConfigMap, newStorageClassName);
+      if (newAccessMode !== accessMode) {
+        setAccessMode(newAccessMode);
+      }
+      if (newVolumeMode !== volumeMode) {
+        setVolumeMode(newVolumeMode);
+      }
+      if (newAccessMode !== accessMode || newVolumeMode !== volumeMode) {
+        setAdvancedDrawerIsOpen(true); // notify the user that the hidden values were changed by force
+      }
     }
+  };
+
+  const onSourceChanged = (uiSource) => {
     setSize('');
     setUnit('Gi');
     setURL('');
     setPVCName('');
     setContainerImage('');
-    setStorageClassName('');
+    onStorageClassNameChanged('');
     onNamespaceChanged(vmNamespace);
     setSource(StorageUISource.fromString(uiSource));
   };
@@ -243,12 +292,16 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
       const newSizeBundle = getPvcStorageSize(
         getLoadedData(persistentVolumeClaims).find((p) => getName(p) === newPVCName),
       );
-      const [newSize, newUnit] = validate.split(newSizeBundle);
+      const [newSize, newUnit] = stringValueUnitSplit(newSizeBundle);
       setSize(newSize);
       setUnit(newUnit);
     }
   };
 
+  const onToggleAdvancedDrawer = () => {
+    setAdvancedDrawerIsOpen(!advancedDrawerIsOpen);
+  };
+
   return (
     <div className="modal-content">
       <ModalTitle>
@@ -258,16 +311,10 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
         <Form>
           <FormRow title="Source" fieldId={asId('source')} isRequired>
             <FormSelect
-              onChange={
-                disableSourceChange || !source.canBeChangedToThisSource(type)
-                  ? undefined
-                  : onSourceChanged
-              }
+              onChange={onSourceChanged}
               value={asFormSelectValue(source)}
               id={asId('source')}
-              isDisabled={
-                inProgress || disableSourceChange || !source.canBeChangedToThisSource(type)
-              }
+              isDisabled={isDisabled('source', !source.canBeChangedToThisSource(type))}
             >
               {StorageUISource.getAll()
                 .filter(
@@ -291,7 +338,7 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
               <TextInput
                 isValid={!isValidationError(urlValidation)}
                 key="url"
-                isDisabled={inProgress}
+                isDisabled={isDisabled('url')}
                 isRequired
                 id={asId('url')}
                 value={url}
@@ -309,7 +356,7 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
               <TextInput
                 isValid={!isValidationError(containerValidation)}
                 key="container"
-                isDisabled={inProgress}
+                isDisabled={isDisabled('container')}
                 isRequired
                 id={asId('container')}
                 value={containerImage}
@@ -319,16 +366,16 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
           )}
           {source.requiresNamespace() && (
             <K8sResourceSelectRow
-              key="namespace"
-              id={asId('namespace')}
-              isDisabled={inProgress}
+              key="pvc-namespace"
+              id={asId('pvc-namespace')}
+              isDisabled={isDisabled('pvcNamespace')}
               name={namespace}
               data={namespaces}
               model={NamespaceModel}
               title={`PVC ${NamespaceModel.label}`}
-              onChange={(sc) => {
+              onChange={(ns) => {
                 setPVCName('');
-                onNamespaceChanged(sc);
+                onNamespaceChanged(ns);
               }}
             />
           )}
@@ -336,7 +383,7 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
             <K8sResourceSelectRow
               key="pvc-select"
               id={asId('pvc')}
-              isDisabled={inProgress || !namespace}
+              isDisabled={isDisabled('pvc', !namespace)}
               isRequired
               name={pvcName}
               validation={pvcValidation}
@@ -357,7 +404,10 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
           >
             <TextInput
               isValid={!isValidationError(nameValidation)}
-              isDisabled={!usedDiskNames || inProgress || !source.isNameEditingSupported(type)}
+              isDisabled={isDisabled(
+                'name',
+                !usedDiskNames || !source.isNameEditingSupported(type),
+              )}
               isRequired
               id={asId('name')}
               value={name}
@@ -373,10 +423,17 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
               unit={unit as BinaryUnit}
               units={source.getAllowedUnits()}
               validation={sizeValidation}
-              isDisabled={inProgress || !source.isSizeEditingSupported()}
+              isDisabled={isDisabled(
+                'size',
+                !source.isSizeEditingSupported(combinedDiskSize?.value),
+              )}
               isRequired
-              onSizeChanged={source.isSizeEditingSupported() ? setSize : undefined}
-              onUnitChanged={source.isSizeEditingSupported() ? setUnit : undefined}
+              onSizeChanged={
+                source.isSizeEditingSupported(combinedDiskSize?.value) ? setSize : undefined
+              }
+              onUnitChanged={
+                source.isSizeEditingSupported(combinedDiskSize?.value) ? setUnit : undefined
+              }
             />
           )}
           {!source.requiresSize() && source.hasDynamicSize() && (
@@ -402,7 +459,7 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
               isValid={!isValidationError(busValidation)}
               value={asFormSelectValue(bus)}
               id={asId('interface')}
-              isDisabled={inProgress}
+              isDisabled={isDisabled('interface')}
             >
               <FormSelectPlaceholderOption isDisabled placeholder="--- Select Interface ---" />
               {!validAllowedBuses.has(bus) && (
@@ -430,12 +487,12 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
             <K8sResourceSelectRow
               key="storage-class"
               id={asId('storage-class')}
-              isDisabled={inProgress}
+              isDisabled={isDisabled('storageClass')}
               name={storageClassName}
               data={storageClasses}
               model={StorageClassModel}
               hasPlaceholder
-              onChange={(sc) => setStorageClassName(sc || '')}
+              onChange={(sc) => onStorageClassNameChanged(sc || '')}
             />
           )}
           {source.isPlainDataVolume(isCreateTemplate) && (
@@ -445,6 +502,63 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
               title="PVC will be created on template creation and used by VMs created from this template."
             />
           )}
+          {source.requiresVolumeModeOrAccessModes() && (
+            <Expandable
+              toggleText="Advanced"
+              isExpanded={advancedDrawerIsOpen}
+              onToggle={onToggleAdvancedDrawer}
+              className="disk-advanced-drawer"
+            >
+              {source.requiresVolumeMode() && (
+                <FormRow title="Volume Mode" fieldId={asId('volume-mode')}>
+                  <FormSelect
+                    onChange={(vMode) => setVolumeMode(VolumeMode.fromString(vMode))}
+                    value={asFormSelectValue(volumeMode?.getValue())}
+                    id={asId('volume-mode')}
+                    isDisabled={isDisabled('volumeMode')}
+                  >
+                    <FormSelectPlaceholderOption
+                      isDisabled={inProgress}
+                      placeholder="--- Select Volume Mode ---"
+                    />
+                    {VolumeMode.getAll().map((v) => (
+                      <FormSelectOption
+                        key={v.getValue()}
+                        value={v.getValue()}
+                        label={`${v.toString()}`}
+                      />
+                    ))}
+                  </FormSelect>
+                </FormRow>
+              )}
+              {source.requiresAccessModes() && (
+                <FormRow
+                  title="Access Mode"
+                  fieldId={asId('access-mode')}
+                  className="disk-access-mode"
+                >
+                  <FormSelect
+                    onChange={(aMode) => setAccessMode(AccessMode.fromString(aMode))}
+                    value={asFormSelectValue(accessMode?.getValue())}
+                    id={asId('access-mode')}
+                    isDisabled={isDisabled('accessMode')}
+                  >
+                    <FormSelectPlaceholderOption
+                      isDisabled={inProgress}
+                      placeholder="--- Select Access Mode ---"
+                    />
+                    {AccessMode.getAll().map((a) => (
+                      <FormSelectOption
+                        key={a.getValue()}
+                        value={a.getValue()}
+                        label={a.toString()}
+                      />
+                    ))}
+                  </FormSelect>
+                </FormRow>
+              )}
+            </Expandable>
+          )}
         </Form>
       </ModalBody>
       <ModalFooter
@@ -466,21 +580,22 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
 
 export type DiskModalProps = {
   disk?: DiskWrapper;
-  disableSourceChange?: boolean;
+  showInitialValidation?: boolean;
   isCreateTemplate?: boolean;
   isEditing?: boolean;
   volume?: VolumeWrapper;
   dataVolume?: DataVolumeWrapper;
   persistentVolumeClaim?: PersistentVolumeClaimWrapper;
+  storageClassConfigMap?: FirehoseResult<ConfigMapKind>;
   onSubmit: (
     disk: DiskWrapper,
     volume: VolumeWrapper,
     dataVolume: DataVolumeWrapper,
     persistentVolumeClaim: PersistentVolumeClaimWrapper,
   ) => Promise<any>;
-  namespaces?: FirehoseResult<K8sResourceKind[]>;
-  storageClasses?: FirehoseResult<K8sResourceKind[]>;
-  persistentVolumeClaims?: FirehoseResult<K8sResourceKind[]>;
+  namespaces?: FirehoseResult;
+  storageClasses?: FirehoseResult;
+  persistentVolumeClaims?: FirehoseResult;
   vmName: string;
   vmNamespace: string;
   namespace: string;
@@ -488,7 +603,6 @@ export type DiskModalProps = {
   templateValidations?: TemplateValidations;
   usedDiskNames: Set<string>;
   usedPVCNames: Set<string>;
+  editConfig?: UIStorageEditConfig;
 } & ModalComponentProps &
   HandlePromiseProps;
-
-export const diskModal = createModalLauncher(DiskModal);
