@@ -1,11 +1,11 @@
 /* eslint-disable lines-between-class-members */
 
-import { ValueEnum, VolumeType } from '../../../constants';
+import { ObjectEnum, VolumeType } from '../../../constants';
 import { DataVolumeSourceType, DiskType } from '../../../constants/vm/storage';
 import { getStringEnumValues } from '../../../utils/types';
 import { BinaryUnit } from '../../form/size-unit-utils';
 
-export class StorageUISource extends ValueEnum<string> {
+export class StorageUISource extends ObjectEnum<string> {
   static readonly BLANK = new StorageUISource(
     'Blank',
     VolumeType.DATA_VOLUME,
@@ -41,7 +41,7 @@ export class StorageUISource extends ValueEnum<string> {
   private readonly hasNewPVC: boolean;
 
   private static readonly ALL = Object.freeze(
-    ValueEnum.getAllClassEnumProperties<StorageUISource>(StorageUISource),
+    ObjectEnum.getAllClassEnumProperties<StorageUISource>(StorageUISource),
   );
 
   private static readonly stringMapper = StorageUISource.ALL.reduce(
@@ -66,9 +66,6 @@ export class StorageUISource extends ValueEnum<string> {
 
   static getAll = () => StorageUISource.ALL;
 
-  static fromSerialized = (volumeType: { value: string }): StorageUISource =>
-    StorageUISource.fromString(volumeType && volumeType.value);
-
   static fromString = (model: string): StorageUISource => StorageUISource.stringMapper[model];
 
   static fromTypes = (
@@ -106,17 +103,27 @@ export class StorageUISource extends ValueEnum<string> {
 
   requiresStorageClass = () => this.requiresDatavolume() || this.hasNewPVC;
 
-  requiresVolume = () => !!this.volumeType;
+  requiresVolumeType = () => !!this.volumeType;
 
   requiresDatavolume = () => !!this.dataVolumeSourceType;
 
   requiresNamespace = () => this === StorageUISource.ATTACH_CLONED_DISK;
 
-  isEditingSupported = () => !this.dataVolumeSourceType; // vm disks - do not support because pvc was already created from DV
+  requiresAccessModes = () =>
+    this !== StorageUISource.ATTACH_DISK &&
+    this !== StorageUISource.CONTAINER &&
+    this !== StorageUISource.OTHER;
+
+  requiresVolumeMode = () =>
+    this !== StorageUISource.ATTACH_DISK &&
+    this !== StorageUISource.CONTAINER &&
+    this !== StorageUISource.OTHER;
+
+  requiresVolumeModeOrAccessModes = () => this.requiresAccessModes() || this.requiresVolumeMode();
 
   isNameEditingSupported = (diskType: DiskType) => diskType !== DiskType.CDROM;
 
-  isSizeEditingSupported = () => this !== StorageUISource.IMPORT_DISK;
+  isSizeEditingSupported = (size: number) => size === 0 || this !== StorageUISource.IMPORT_DISK; // if imported disk has 0 size, leave the user to decide
 
   isPlainDataVolume = (isCreateTemplate: boolean) =>
     isCreateTemplate && this === StorageUISource.URL;
