@@ -1,16 +1,14 @@
 import * as React from 'react';
 import * as _ from 'lodash';
-import {
-  DashboardCard,
-  DashboardCardBody,
-  DashboardCardHeader,
-  DashboardCardHelp,
-  DashboardCardTitle,
-} from '@console/internal/components/dashboard/dashboard-card';
+import DashboardCard from '@console/shared/src/components/dashboard/dashboard-card/DashboardCard';
+import DashboardCardBody from '@console/shared/src/components/dashboard/dashboard-card/DashboardCardBody';
+import DashboardCardHeader from '@console/shared/src/components/dashboard/dashboard-card/DashboardCardHeader';
+import DashboardCardTitle from '@console/shared/src/components/dashboard/dashboard-card/DashboardCardTitle';
+import { FieldLevelHelp } from '@console/internal/components/utils/index';
 import {
   DashboardItemProps,
   withDashboardResources,
-} from '@console/internal/components/dashboards-page/with-dashboard-resources';
+} from '@console/internal/components/dashboard/with-dashboard-resources';
 import { PrometheusResponse } from '@console/internal/components/graphs';
 import { getMetric } from '../../utils';
 import { ResourceProvidersBody } from './resource-providers-card-body';
@@ -35,7 +33,7 @@ const filterProviders = (allProviders: ProviderType): string[] => {
 const createProvidersList = (data: PrometheusResponse): ProviderType => {
   const providers = _.get(data, 'data.result', null);
   const providersList: ProviderType = {};
-  if (_.isNil(providers)) return null;
+  if (_.isNil(providers)) return {};
   providers.forEach((provider) => {
     providersList[getProviderType(provider)] = getProviderCount(provider);
   });
@@ -58,17 +56,36 @@ const ResourceProviders: React.FC<DashboardItemProps> = ({
 
   const providersTypesQueryResult = prometheusResults.getIn([
     RESOURCE_PROVIDERS_QUERY.PROVIDERS_TYPES,
-    'result',
+    'data',
+  ]) as PrometheusResponse;
+  const providersTypesQueryResultError = prometheusResults.getIn([
+    RESOURCE_PROVIDERS_QUERY.PROVIDERS_TYPES,
+    'loadError',
   ]);
+
   const unhealthyProvidersTypesQueryResult = prometheusResults.getIn([
     RESOURCE_PROVIDERS_QUERY.UNHEALTHY_PROVIDERS_TYPES,
-    'result',
+    'data',
+  ]) as PrometheusResponse;
+  const unhealthyProvidersTypesQueryResultError = prometheusResults.getIn([
+    RESOURCE_PROVIDERS_QUERY.UNHEALTHY_PROVIDERS_TYPES,
+    'loadError',
   ]);
+
   const resourcesLinksResponse = prometheusResults.getIn([
     RESOURCE_PROVIDERS_QUERY.RESOURCES_LINK_QUERY,
-    'result',
+    'data',
+  ]) as PrometheusResponse;
+  const resourcesLinksResponseError = prometheusResults.getIn([
+    RESOURCE_PROVIDERS_QUERY.RESOURCES_LINK_QUERY,
+    'loadError',
   ]);
 
+  const error =
+    !!providersTypesQueryResultError ||
+    !!unhealthyProvidersTypesQueryResultError ||
+    !!resourcesLinksResponseError;
+
   const noobaaResourcesLink = getMetric(resourcesLinksResponse, 'resources');
 
   const allProviders = createProvidersList(providersTypesQueryResult);
@@ -80,16 +97,17 @@ const ResourceProviders: React.FC<DashboardItemProps> = ({
     <DashboardCard>
       <DashboardCardHeader>
         <DashboardCardTitle>Resource Providers</DashboardCardTitle>
-        <DashboardCardHelp>
+        <FieldLevelHelp>
           A list of all MCG (Multi-cloud gateway) resources that are currently in use. Those
           resources are used to store data according to the buckets policies and can be a
           cloud-based resource or a bare metal resource.
-        </DashboardCardHelp>
+        </FieldLevelHelp>
       </DashboardCardHeader>
       <DashboardCardBody>
         <ResourceProvidersBody
-          isLoading={!(providersTypesQueryResult && unhealthyProvidersTypesQueryResult)}
-          hasProviders={!_.isEmpty(allProviders) || !_.isNil(allProviders)}
+          isLoading={!error && !(providersTypesQueryResult && unhealthyProvidersTypesQueryResult)}
+          hasProviders={!_.isEmpty(allProviders)}
+          error={error}
         >
           {providerTypes.map((provider) => (
             <ResourceProvidersItem
