@@ -24,6 +24,7 @@ export enum SpecCapability {
   select = 'urn:alm:descriptor:com.tectonic.ui:select:',
   advanced = 'urn:alm:descriptor:com.tectonic.ui:advanced',
   fieldDependency = 'urn:alm:descriptor:com.tectonic.ui:fieldDependency:',
+  hidden = 'urn:alm:descriptor:com.tectonic.ui:hidden',
 }
 
 export enum StatusCapability {
@@ -37,22 +38,27 @@ export enum StatusCapability {
   k8sPhaseReason = 'urn:alm:descriptor:io.kubernetes.phase:reason',
   // Prefix for all kubernetes resource status descriptors.
   k8sResourcePrefix = 'urn:alm:descriptor:io.kubernetes:',
+  hidden = 'urn:alm:descriptor:com.tectonic.ui:hidden',
 }
 
-export type Descriptor = {
+export type Descriptor<T = any> = {
   path: string;
   displayName: string;
   description: string;
-  'x-descriptors': StatusCapability[] | SpecCapability[];
+  'x-descriptors'?: T[];
   value?: any;
 };
 
+export type SpecDescriptor = Descriptor<SpecCapability>;
+export type StatusDescriptor = Descriptor<StatusCapability>;
+
 export type DescriptorProps = {
   descriptor: Descriptor;
   value: any;
   obj: K8sResourceKind;
   model: K8sKind;
   namespace?: string;
+  onHandleError?: (message: string) => void;
 };
 
 export type CapabilityProps<C extends SpecCapability | StatusCapability> = {
@@ -62,4 +68,7 @@ export type CapabilityProps<C extends SpecCapability | StatusCapability> = {
   obj?: K8sResourceKind;
   model?: K8sKind;
   namespace?: string;
+  onHandleError?: (message: string) => void;
 };
+
+export type Error = { message: string };
