@@ -19,7 +19,7 @@ const LayerContainer: React.RefForwardingComponent<SVGGElement, LayerContainerPr
   let y = 0;
   while (isNode(p)) {
     if (!p.isGroup() || p.isCollapsed()) {
-      const { x: px, y: py } = p.getBounds();
+      const { x: px, y: py } = p.getPosition();
       x += px;
       y += py;
     }
