@@ -4,8 +4,9 @@ export enum ActionType {
   SetMonitoringURL = 'setMonitoringURL',
 }
 
-export const setMonitoringURL = (name: string, url: string) => action(ActionType.SetMonitoringURL, {name, url});
+export const setMonitoringURL = (name: string, url: string) =>
+  action(ActionType.SetMonitoringURL, { name, url });
 
-const monitoringActions = {setMonitoringURL};
+const monitoringActions = { setMonitoringURL };
 
 export type MonitoringAction = Action<typeof monitoringActions>;
