@@ -2,7 +2,7 @@ import * as React from 'react';
 import * as _ from 'lodash-es';
 import * as classNames from 'classnames';
 
-import { K8sResourceKind, TemplateKind } from '../../module/k8s';
+import { K8sResourceKind, TemplateKind, PartialObjectMetadata } from '../../module/k8s';
 import * as threeScaleImg from '../../imgs/logos/3scale.svg';
 import * as aerogearImg from '../../imgs/logos/aerogear.svg';
 import * as amqImg from '../../imgs/logos/amq.svg';
@@ -58,6 +58,7 @@ import * as mysqlDatabaseImg from '../../imgs/logos/mysql-database.svg';
 import * as nginxImg from '../../imgs/logos/nginx.svg';
 import * as nodejsImg from '../../imgs/logos/nodejs.svg';
 import * as openjdkImg from '../../imgs/logos/openjdk.svg';
+import * as redhatImg from '../../imgs/logos/redhat.svg';
 import * as openlibertyImg from '../../imgs/logos/openliberty.svg';
 import * as openshiftImg from '../../imgs/logos/openshift.svg';
 import * as openstackImg from '../../imgs/logos/openstack.svg';
@@ -75,11 +76,13 @@ import * as rabbitmqImg from '../../imgs/logos/rabbitmq.svg';
 import * as railsImg from '../../imgs/logos/rails.svg';
 import * as redisImg from '../../imgs/logos/redis.svg';
 import * as rhIntegrationImg from '../../imgs/logos/rh-integration.svg';
+import * as rhSpringBoot from '../../imgs/logos/rh-spring-boot.svg';
 import * as rhTomcatImg from '../../imgs/logos/rh-tomcat.svg';
 import * as rubyImg from '../../imgs/logos/ruby.svg';
 import * as scalaImg from '../../imgs/logos/scala.svg';
 import * as shadowmanImg from '../../imgs/logos/shadowman.svg';
 import * as springImg from '../../imgs/logos/spring.svg';
+import * as springBootImg from '../../imgs/logos/spring-boot.svg';
 import * as ssoImg from '../../imgs/logos/sso.svg';
 import * as stackoverflowImg from '../../imgs/logos/stackoverflow.svg';
 import * as suseImg from '../../imgs/logos/suse.svg';
@@ -167,14 +170,17 @@ const logos = new Map()
   .set('icon-rails', railsImg)
   .set('icon-redis', redisImg)
   .set('icon-rh-integration', rhIntegrationImg)
+  .set('icon-rh-spring-boot', rhSpringBoot)
   .set('icon-java', openjdkImg)
   // Use the upstream icon.
+  .set('icon-redhat', redhatImg)
   .set('icon-rh-openjdk', openjdkImg)
   .set('icon-rh-tomcat', rhTomcatImg)
   .set('icon-ruby', rubyImg)
   .set('icon-scala', scalaImg)
   .set('icon-shadowman', shadowmanImg)
   .set('icon-spring', springImg)
+  .set('icon-spring-boot', springBootImg)
   .set('icon-sso', ssoImg)
   .set('icon-stackoverflow', stackoverflowImg)
   .set('icon-suse', suseImg)
@@ -214,7 +220,7 @@ export const getImageStreamIcon = (tag: string): string => {
   return _.get(tag, 'annotations.iconClass');
 };
 
-export const getTemplateIcon = (template: TemplateKind): string => {
+export const getTemplateIcon = (template: TemplateKind | PartialObjectMetadata): string => {
   return _.get(template, 'metadata.annotations.iconClass');
 };
 
