@@ -3,8 +3,9 @@ import { Link } from 'react-router-dom';
 import * as classNames from 'classnames';
 import { sortable } from '@patternfly/react-table';
 
+import { AddHealthChecks, EditHealthChecks } from '@console/app/src/actions/modify-health-checks';
 import { K8sResourceKind } from '../module/k8s';
-import { DetailsPage, ListPage, Table, TableRow, TableData } from './factory';
+import { DetailsPage, ListPage, Table, TableRow, TableData, RowFunction } from './factory';
 import {
   AsyncComponent,
   DetailsItem,
@@ -14,19 +15,24 @@ import {
   detailsPage,
   LabelList,
   navFactory,
+  PodsComponent,
   ResourceKebab,
   ResourceLink,
   ResourceSummary,
   SectionHeading,
   Selector,
+  LoadingInline,
 } from './utils';
 import { ResourceEventStream } from './events';
 import { VolumesTable } from './volumes-table';
 import { DaemonSetModel } from '../models';
+import { PodRingController, PodRing } from '@console/shared';
 
 export const menuActions: KebabAction[] = [
+  AddHealthChecks,
   Kebab.factory.AddStorage,
   ...Kebab.getExtensionsActionsForKind(DaemonSetModel),
+  EditHealthChecks,
   ...Kebab.factory.common,
 ];
 
@@ -81,17 +87,7 @@ const DaemonSetTableHeader = () => {
 };
 DaemonSetTableHeader.displayName = 'DaemonSetTableHeader';
 
-const DaemonSetTableRow = ({
-  obj: daemonset,
-  index,
-  key,
-  style,
-}: {
-  obj: K8sResourceKind;
-  index: number;
-  key: string;
-  style: any;
-}) => {
+const DaemonSetTableRow: RowFunction<K8sResourceKind> = ({ obj: daemonset, index, key, style }) => {
   return (
     <TableRow id={daemonset.metadata.uid} index={index} trKey={key} style={style}>
       <TableData className={tableColumnClasses[0]}>
@@ -130,7 +126,6 @@ const DaemonSetTableRow = ({
     </TableRow>
   );
 };
-DaemonSetTableRow.displayName = 'DaemonSetTableRow';
 
 export const DaemonSetDetailsList: React.FC<DaemonSetDetailsListProps> = ({ ds }) => (
   <dl className="co-m-pane__details">
@@ -143,6 +138,23 @@ const DaemonSetDetails: React.FC<DaemonSetDetailsProps> = ({ obj: daemonset }) =
   <>
     <div className="co-m-pane__body">
       <SectionHeading text="Daemon Set Details" />
+      <PodRingController
+        namespace={daemonset.metadata.namespace}
+        kind={daemonset.kind}
+        render={(d) => {
+          return d.loaded ? (
+            <PodRing
+              key={daemonset.metadata.uid}
+              pods={d.data[daemonset.metadata.uid].pods}
+              obj={daemonset}
+              resourceKind={DaemonSetModel}
+              enableScaling={false}
+            />
+          ) : (
+            <LoadingInline />
+          );
+        }}
+      />
       <div className="row">
         <div className="col-lg-6">
           <ResourceSummary resource={daemonset} showPodSelector showNodeSelector showTolerations />
@@ -193,6 +205,10 @@ export const DaemonSetsPage: React.FC<DaemonSetsPageProps> = (props) => (
   <ListPage canCreate={true} ListComponent={DaemonSets} kind={kind} {...props} />
 );
 
+const DaemonSetPods: React.FC<DaemonSetPodsProps> = (props) => (
+  <PodsComponent {...props} customData={{ showNodes: true }} />
+);
+
 export const DaemonSetsDetailsPage: React.FC<DaemonSetsDetailsPageProps> = (props) => (
   <DetailsPage
     {...props}
@@ -201,7 +217,7 @@ export const DaemonSetsDetailsPage: React.FC<DaemonSetsDetailsPageProps> = (prop
     pages={[
       details(detailsPage(DaemonSetDetails)),
       editYaml(),
-      pods(),
+      pods(DaemonSetPods),
       envEditor(EnvironmentTab),
       events(ResourceEventStream),
     ]}
@@ -233,6 +249,10 @@ type DaemonSetsPageProps = {
   selector?: any;
 };
 
+type DaemonSetPodsProps = {
+  obj: K8sResourceKind;
+};
+
 type DaemonSetsDetailsPageProps = {
   match: any;
 };
