@@ -12,6 +12,7 @@ import {
   KebabOptionsCreator,
   Page,
   AsyncComponent,
+  PageComponentProps,
 } from '../utils';
 import {
   K8sResourceKindReference,
@@ -25,30 +26,32 @@ import { breadcrumbsForDetailsPage } from '../utils/breadcrumbs';
 
 export const DetailsPage = withFallback<DetailsPageProps>(({ pages = [], ...props }) => {
   const resourceKeys = _.map(props.resources, 'prop');
+
+  const renderAsyncComponent = (page: ResourceTabPage, cProps: PageComponentProps) => (
+    <AsyncComponent loader={page.properties.loader} {...cProps} />
+  );
+
   const resourcePageExtensions = useExtensions<ResourceTabPage>(isResourceTabPage);
-  let allPages = [
-    ...pages,
-    ...resourcePageExtensions
-      .filter(
-        (p) =>
-          referenceForModel(p.properties.model) ===
-          (props.kindObj ? referenceFor(props.kindObj) : props.kind),
-      )
-      .map((p) => ({
-        href: p.properties.href,
-        name: p.properties.name,
-        component: () => (
-          <AsyncComponent
-            loader={p.properties.loader}
-            namespace={props.namespace}
-            name={props.name}
-            kind={props.kind}
-            match={props.match}
-          />
-        ),
-      })),
-  ];
+
+  const pluginPages = React.useMemo(
+    () =>
+      resourcePageExtensions
+        .filter(
+          (p) =>
+            referenceForModel(p.properties.model) ===
+            (props.kindObj ? referenceFor(props.kindObj) : props.kind),
+        )
+        .map((p) => ({
+          href: p.properties.href,
+          name: p.properties.name,
+          component: (cProps) => renderAsyncComponent(p, cProps),
+        })),
+    [resourcePageExtensions, props],
+  );
+
+  let allPages = [...pages, ...pluginPages];
   allPages = allPages.length ? allPages : null;
+
   return (
     <Firehose
       resources={[
