@@ -4,8 +4,9 @@ import { sortable } from '@patternfly/react-table';
 import * as classNames from 'classnames';
 
 import { MachineHealthCheckModel, MachineModel } from '../models';
-import { K8sResourceKind, referenceForModel } from '../module/k8s';
-import { DetailsPage, ListPage, Table, TableRow, TableData } from './factory';
+import { K8sResourceKind, MachineHealthCheckKind } from '../module/k8s/types';
+import { referenceForModel } from '../module/k8s/k8s';
+import { DetailsPage, ListPage, Table, TableRow, TableData, RowFunction } from './factory';
 import {
   DetailsItem,
   EmptyBox,
@@ -15,9 +16,9 @@ import {
   ResourceSummary,
   SectionHeading,
   Selector,
+  Timestamp,
   navFactory,
 } from './utils';
-import { fromNow } from './utils/datetime';
 
 const { common } = Kebab.factory;
 const menuActions = [...Kebab.getExtensionsActionsForKind(MachineHealthCheckModel), ...common];
@@ -58,12 +59,7 @@ const MachineHealthCheckTableHeader = () => {
 };
 MachineHealthCheckTableHeader.displayName = 'MachineHealthCheckTableHeader';
 
-const MachineHealthCheckTableRow: React.FC<MachineHealthCheckTableRowProps> = ({
-  obj,
-  index,
-  key,
-  style,
-}) => {
+const MachineHealthCheckTableRow: RowFunction<K8sResourceKind> = ({ obj, index, key, style }) => {
   return (
     <TableRow id={obj.metadata.uid} index={index} trKey={key} style={style}>
       <TableData className={tableColumnClasses[0]}>
@@ -77,7 +73,7 @@ const MachineHealthCheckTableRow: React.FC<MachineHealthCheckTableRowProps> = ({
         <ResourceLink kind="Namespace" name={obj.metadata.namespace} />
       </TableData>
       <TableData className={tableColumnClasses[2]}>
-        {fromNow(obj.metadata.creationTimestamp)}
+        <Timestamp timestamp={obj.metadata.creationTimestamp} />
       </TableData>
       <TableData className={tableColumnClasses[3]}>
         <ResourceKebab actions={menuActions} kind={machineHealthCheckReference} resource={obj} />
@@ -85,13 +81,6 @@ const MachineHealthCheckTableRow: React.FC<MachineHealthCheckTableRowProps> = ({
     </TableRow>
   );
 };
-MachineHealthCheckTableRow.displayName = 'MachineHealthCheckTableRow';
-type MachineHealthCheckTableRowProps = {
-  obj: K8sResourceKind;
-  index: number;
-  key?: string;
-  style: object;
-};
 
 const MachineHealthCheckList: React.FC = (props) => (
   <Table
@@ -191,7 +180,7 @@ type MachineHealthCheckPageProps = {
 };
 
 export type MachineHealthCheckDetailsProps = {
-  obj: K8sResourceKind;
+  obj: MachineHealthCheckKind;
 };
 
 export type MachineHealthCheckDetailsPageProps = {
