@@ -60,11 +60,7 @@ export class SyncMarkdownView extends React.Component<
   }
 
   updateDimensions() {
-    if (
-      !this.frame ||
-      !this.frame.contentWindow.document.body ||
-      !this.frame.contentWindow.document.body.firstChild
-    ) {
+    if (!this.frame?.contentWindow?.document.body.firstChild) {
       return;
     }
     this.frame.style.height = `${this.frame.contentWindow.document.body.firstChild.scrollHeight}px`;
@@ -104,14 +100,15 @@ export class SyncMarkdownView extends React.Component<
         min-width: auto !important;
       }
       table {
+        display: block;
         margin-bottom: 11.5px;
+        overflow-x: auto;
       }
       td,
       th {
         border-bottom: 1px solid #ededed;
         padding: 10px;
         vertical-align: top;
-        word-break: break-word;
       }
       th {
         padding-top: 0;
