@@ -17,7 +17,7 @@ import {
 import { K8sResourceKind } from '../../module/k8s';
 import { history, Kebab, MsgBox, SectionHeading, StatusBox } from '../utils';
 import { confirmModal, createAlertRoutingModal } from '../modals';
-import { Table, TableData, TableRow, TextFilter } from '../factory';
+import { Table, TableData, TableRow, TextFilter, RowFunction } from '../factory';
 import {
   getAlertmanagerConfig,
   patchAlertmanagerConfig,
@@ -29,6 +29,12 @@ import { PencilAltIcon } from '@patternfly/react-icons';
 let secret: K8sResourceKind = null; // alertmanager-main Secret which holds alertmanager configuration yaml
 let config: AlertmanagerConfig = null; // alertmanager configuration yaml as object
 
+export enum InitialReceivers {
+  Critical = 'Critical',
+  Default = 'Default',
+  Watchdog = 'Watchdog',
+}
+
 const AlertRouting = () => {
   const groupBy = _.get(config, ['route', 'group_by'], []);
   return (
@@ -44,10 +50,14 @@ const AlertRouting = () => {
       </SectionHeading>
       <div className="row">
         <div className="col-sm-6">
-          <dt>Group By</dt>
-          <dd data-test-id="group_by_value">{_.isEmpty(groupBy) ? '-' : _.join(groupBy, ', ')}</dd>
-          <dt>Group Wait</dt>
-          <dd data-test-id="group_wait_value">{_.get(config, ['route', 'group_wait'], '-')}</dd>
+          <dl className="co-m-pane__details">
+            <dt>Group By</dt>
+            <dd data-test-id="group_by_value">
+              {_.isEmpty(groupBy) ? '-' : _.join(groupBy, ', ')}
+            </dd>
+            <dt>Group Wait</dt>
+            <dd data-test-id="group_wait_value">{_.get(config, ['route', 'group_wait'], '-')}</dd>
+          </dl>
         </div>
         <div className="col-sm-6">
           <dl className="co-m-pane__details">
@@ -175,11 +185,20 @@ const hasSimpleReceiver = (
   return false;
 };
 
-const hasIncompleteDefaultReceiver = () => {
+const numberOfIncompleteReceivers = (): number => {
   const { route, receivers } = config;
   const { receiver: defaultReceiverName } = route;
-  const defaultReceiver = _.filter(receivers, { name: defaultReceiverName });
-  return defaultReceiver.length === 1 && _.isEmpty(getIntegrationTypes(defaultReceiver[0]));
+
+  const defaultReceiver = receivers.filter((receiver) => receiver.name === defaultReceiverName);
+  const criticalReceiver = receivers.filter(
+    (receiver) => receiver.name === InitialReceivers.Critical,
+  );
+
+  const numIncompleteReceivers: number = _.isEmpty(getIntegrationTypes(defaultReceiver[0])) ? 1 : 0;
+
+  return _.isEmpty(getIntegrationTypes(criticalReceiver[0]))
+    ? numIncompleteReceivers + 1
+    : numIncompleteReceivers;
 };
 
 // Puts sets of key=value pairs into single comma delimited label
@@ -249,13 +268,13 @@ const receiverMenuItems = (receiverName: string, canDelete: boolean, canUseEditF
   },
 ];
 
-const ReceiverTableRow: React.FC<ReceiverTableRowProps> = ({
-  obj: receiver,
-  index,
-  key,
-  style,
-  customData,
-}) => {
+const ReceiverTableRow: RowFunction<
+  AlertmanagerReceiver,
+  {
+    routingLabelsByReceivers: RoutingLabelsByReceivers[];
+    defaultReceiverName: string;
+  }
+> = ({ obj: receiver, index, key, style, customData }) => {
   const { routingLabelsByReceivers, defaultReceiverName } = customData;
   // filter to routing labels belonging to current Receiver
   const receiverRoutingLabels = _.filter(routingLabelsByReceivers, { receiver: receiver.name });
@@ -279,7 +298,9 @@ const ReceiverTableRow: React.FC<ReceiverTableRowProps> = ({
     <TableRow id={index} index={index} trKey={key} style={style}>
       <TableData className={tableColumnClasses[0]}>{receiver.name}</TableData>
       <TableData className={tableColumnClasses[1]}>
-        {!integrationTypesLabel ? (
+        {(receiver.name === InitialReceivers.Critical ||
+          receiver.name === InitialReceivers.Default) &&
+        !integrationTypesLabel ? (
           <Link to={`/monitoring/alertmanagerconfig/receivers/${receiver.name}/edit`}>
             <PencilAltIcon className="co-icon-space-r pf-c-button-icon--plain" />
             Configure
@@ -300,7 +321,6 @@ const ReceiverTableRow: React.FC<ReceiverTableRowProps> = ({
     </TableRow>
   );
 };
-ReceiverTableRow.displayName = 'ReceiverTableRow';
 
 const ReceiversTable: React.FC<ReceiverTableProps> = (props) => {
   const { filterValue } = props;
@@ -345,6 +365,7 @@ const Receivers = () => {
     receivers = receivers.filter((receiver) => fuzzy(filterStr, _.toLower(receiver.name)));
   }
 
+  const numOfIncompleteReceivers = numberOfIncompleteReceivers();
   return (
     <div className="co-m-pane__body">
       <SectionHeading text="Receivers" />
@@ -360,20 +381,20 @@ const Receivers = () => {
           <TextFilter
             defaultValue=""
             label="Receivers by Name"
-            onChange={(e) => setReceiverFilter(e.target.value)}
+            onChange={(val) => setReceiverFilter(val)}
           />
         </div>
       </div>
-      {hasIncompleteDefaultReceiver() && (
+      {numOfIncompleteReceivers > 0 && (
         <Alert
           isInline
           className="co-alert co-alert--scrollable"
           variant="info"
-          title="Incomplete Default Receiver"
+          title={`Incomplete Alert Receiver${numOfIncompleteReceivers > 1 ? 's' : ''}`}
         >
           <div className="co-pre-line">
-            Configure this receiver to ensure that you learn about important issues with your
-            cluster.
+            Configure {numOfIncompleteReceivers === 1 ? 'this receiver' : 'these receivers'} to
+            ensure that you learn about important issues with your cluster.
           </div>
         </Alert>
       )}
@@ -486,17 +507,6 @@ type ReceiverTableProps = {
   filterValue?: string;
 };
 
-type ReceiverTableRowProps = {
-  obj: AlertmanagerReceiver;
-  index: number;
-  key?: string;
-  style: object;
-  customData: {
-    routingLabelsByReceivers: RoutingLabelsByReceivers[];
-    defaultReceiverName: string;
-  };
-};
-
 type RoutingLabelProps = {
   labels: { [key: string]: string };
 };
