@@ -1,4 +1,5 @@
 import * as React from 'react';
+import * as _ from 'lodash';
 import { connect } from 'react-redux';
 
 import * as UIActions from '../../actions/ui';
@@ -20,12 +21,13 @@ const getResourceTabComp = (t) => (props) => (
 );
 
 const getPluginTabResources = (item, tabs): ResourceOverviewDetailsProps['tabs'] => {
-  const tabEntry = plugins.registry
+  let tabEntry = plugins.registry
     .getOverviewResourceTabs()
     .filter((tab) => item[tab.properties.key]);
-  const newTabs = tabs.map((tab) => {
+  const overridenTabs = tabs.map((tab) => {
     const tabEntryConfig = tabEntry.find((t) => tab.name === t.properties.name);
     if (tabEntryConfig) {
+      tabEntry = tabEntry.filter((entry) => tab.name !== entry.properties.name);
       return {
         name: tab.name,
         component: getResourceTabComp(tabEntryConfig),
@@ -33,7 +35,16 @@ const getPluginTabResources = (item, tabs): ResourceOverviewDetailsProps['tabs']
     }
     return tab;
   });
-  return newTabs;
+
+  /** Add new tabs from plugin */
+  const newTabs = tabEntry.map((entry) => {
+    return {
+      name: entry.properties.name,
+      component: getResourceTabComp(entry),
+    };
+  });
+
+  return overridenTabs.concat(newTabs);
 };
 
 export const ResourceOverviewDetails = connect<PropsFromState, PropsFromDispatch, OwnProps>(
@@ -47,18 +58,33 @@ export const ResourceOverviewDetails = connect<PropsFromState, PropsFromDispatch
     onClickTab,
     selectedDetailsTab,
     tabs,
-  }: ResourceOverviewDetailsProps) => (
-    <div className="overview__sidebar-pane resource-overview">
-      <ResourceOverviewHeading actions={menuActions} kindObj={kindObj} resource={item.obj} />
-      <SimpleTabNav
-        onClickTab={onClickTab}
-        selectedTab={selectedDetailsTab}
-        tabProps={{ item }}
-        tabs={getPluginTabResources(item, tabs)}
-        additionalClassNames="co-m-horizontal-nav__menu--within-sidebar co-m-horizontal-nav__menu--within-overview-sidebar"
-      />
-    </div>
-  ),
+  }: ResourceOverviewDetailsProps) => {
+    const keys = Object.keys(item);
+    const keysRef = React.useRef(keys);
+    const tabsRef = React.useRef(tabs);
+    const pluginTabsRef = React.useRef<React.ComponentProps<typeof SimpleTabNav>['tabs']>();
+    if (
+      !pluginTabsRef.current ||
+      !_.isEqual(keys, keysRef.current) ||
+      !_.isEqual(tabs, tabsRef.current)
+    ) {
+      keysRef.current = keys;
+      tabsRef.current = tabs;
+      pluginTabsRef.current = getPluginTabResources(item, tabs);
+    }
+    return (
+      <div className="overview__sidebar-pane resource-overview">
+        <ResourceOverviewHeading actions={menuActions} kindObj={kindObj} resource={item.obj} />
+        <SimpleTabNav
+          onClickTab={onClickTab}
+          selectedTab={selectedDetailsTab}
+          tabProps={{ item }}
+          tabs={pluginTabsRef.current}
+          additionalClassNames="co-m-horizontal-nav__menu--within-sidebar co-m-horizontal-nav__menu--within-overview-sidebar"
+        />
+      </div>
+    );
+  },
 );
 
 type PropsFromState = {
@@ -77,6 +103,7 @@ type OwnProps = {
     name: string;
     component: any;
   }[];
+  isOperatorBacked?: boolean;
 };
 
 export type ResourceOverviewDetailsProps = PropsFromState & PropsFromDispatch & OwnProps;
