@@ -169,6 +169,7 @@ export const PodExec = connectToFlags(FLAGS.OPENSHIFT)(
 
     render() {
       const { containers, activeContainer, open, error } = this.state;
+      const { message } = this.props;
 
       let contents = <LoadingBox />;
       if (error) {
@@ -206,6 +207,7 @@ export const PodExec = connectToFlags(FLAGS.OPENSHIFT)(
               </div>
             )}
           </div>
+          {message}
           {contents}
         </div>
       );
