@@ -253,7 +253,18 @@ export const EnvFromEditor = withDragDropContext(
     }
 
     render() {
-      const { nameValuePairs, readOnly, nameValueId, configMaps, secrets } = this.props;
+      const {
+        nameValuePairs,
+        readOnly,
+        nameValueId,
+        configMaps,
+        secrets,
+        serviceAccounts,
+        firstTitle,
+        secondTitle,
+        addButtonDisabled,
+        addButtonLabel,
+      } = this.props;
       const pairElems = nameValuePairs.map((pair, i) => {
         const key = _.get(pair, [EnvFromPair.Index], i);
 
@@ -271,6 +282,7 @@ export const EnvFromEditor = withDragDropContext(
             rowSourceId={nameValueId}
             configMaps={configMaps}
             secrets={secrets}
+            serviceAccounts={serviceAccounts}
           />
         );
       });
@@ -279,8 +291,8 @@ export const EnvFromEditor = withDragDropContext(
         <>
           <div className="row pairs-list__heading">
             {!readOnly && <div className="col-xs-1 co-empty__header" />}
-            <div className="col-xs-5 text-secondary text-uppercase">Config Map/Secret</div>
-            <div className="col-xs-5 text-secondary text-uppercase">Prefix (Optional)</div>
+            <div className="col-xs-5 text-secondary text-uppercase">{firstTitle}</div>
+            <div className="col-xs-5 text-secondary text-uppercase">{secondTitle}</div>
             <div className="col-xs-1 co-empty__header" />
           </div>
           {pairElems}
@@ -292,8 +304,9 @@ export const EnvFromEditor = withDragDropContext(
                   onClick={this._append}
                   type="button"
                   variant="link"
+                  isDisabled={addButtonDisabled}
                 >
-                  <PlusCircleIcon /> Add All From Config Map or Secret
+                  <PlusCircleIcon /> {addButtonLabel}
                 </Button>
               )}
             </div>
@@ -318,10 +331,18 @@ EnvFromEditor.propTypes = {
   updateParentData: PropTypes.func.isRequired,
   configMaps: PropTypes.object,
   secrets: PropTypes.object,
+  serviceAccounts: PropTypes.object,
+  firstTitle: PropTypes.string,
+  secondTitle: PropTypes.string,
+  addButtonDisabled: PropTypes.bool,
 };
 EnvFromEditor.defaultProps = {
   readOnly: false,
   nameValueId: 0,
+  firstTitle: 'Config map/secret',
+  secondTitle: 'Prefix (Optional)',
+  addButtonDisabled: false,
+  addButtonLabel: 'Add All From Config Map or Secret',
 };
 
 const pairSource = {
@@ -595,6 +616,7 @@ const EnvFromPairElement = DragSource(
           pair,
           configMaps,
           secrets,
+          serviceAccounts,
         } = this.props;
         const deleteButton = (
           <>
@@ -630,6 +652,7 @@ const EnvFromPairElement = DragSource(
                   pair={pair[EnvFromPair.Resource]}
                   configMaps={configMaps}
                   secrets={secrets}
+                  serviceAccounts={serviceAccounts}
                   onChange={this._onChangeResource}
                   disabled={readOnly}
                 />
@@ -649,6 +672,7 @@ const EnvFromPairElement = DragSource(
                 <div className="col-xs-1 pairs-list__action">
                   <Button
                     type="button"
+                    data-test-id="pairs-list__delete-from-btn"
                     className="pairs-list__span-btns"
                     onClick={this._onRemove}
                     variant="plain"
