@@ -15,7 +15,11 @@ const ADMIN_RESOURCES = new Set([
   'secrets',
 ]);
 
-export const kindToAbbr = (kind) => (kind.replace(/[^A-Z]/g, '') || kind.toUpperCase()).slice(0, 3);
+const abbrBlacklist = ['ASS'];
+export const kindToAbbr = (kind) => {
+  const abbrKind = (kind.replace(/[^A-Z]/g, '') || kind.toUpperCase()).slice(0, 3);
+  return abbrBlacklist.includes(abbrKind) ? abbrKind.slice(0, -1) : abbrKind;
+};
 
 export const cacheResources = (resources) =>
   new Promise<void>((resolve, reject) => {
